@@ -49,11 +49,7 @@
 package com.openexchange.usm.api.contenttypes;
 
 import java.io.Serializable;
-
-import com.openexchange.usm.api.datatypes.PIMAttachment;
-import com.openexchange.usm.api.datatypes.PIMAttachments;
 import com.openexchange.usm.api.exceptions.DeserializationFailedException;
-import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.Session;
 
