@@ -48,8 +48,10 @@
  */
 package com.openexchange.usm.api.datatypes;
 
-import org.json.*;
-
+import java.io.Serializable;
+import org.json.JSONArray;
+import org.json.JSONException;
+import org.json.JSONObject;
 import com.openexchange.usm.api.session.Session;
 
 /**
@@ -100,6 +102,28 @@ public class ArrayDataType implements DataType<Object[]> {
 		return result;
 	}
 
+    public Serializable serialize(Object value) {
+        Object[] source = (Object[]) value;
+        if (source.length == 0)
+            return source;
+        Object[] result = new Object[source.length];
+        for (int i = 0; i < result.length; i++) {
+            result[i] = _elementType.serialize(source[i]);
+        }
+        return result;
+    }
+
+    public Object[] deserialize(Serializable value) {
+        Object[] source = (Object[]) value;
+        if (source.length == 0)
+            return source;
+        Object[] result = new Object[source.length];
+        for (int i = 0; i < result.length; i++) {
+            result[i] = _elementType.deserialize((Serializable) source[i]);
+        }
+        return result;
+    }
+
 	public Object[] createNewObject() {
 		return EMPTY_ARRAY;
 	}
