@@ -48,8 +48,9 @@
  */
 package com.openexchange.usm.api.datatypes;
 
-import org.json.*;
-
+import org.json.JSONArray;
+import org.json.JSONException;
+import org.json.JSONObject;
 import com.openexchange.usm.api.session.Session;
 
 /**
