@@ -48,7 +48,12 @@
  */
 package com.openexchange.usm.contenttypes.calendar.impl;
 
-import static com.openexchange.usm.api.datatypes.DataTypes.*;
+import static com.openexchange.usm.api.datatypes.DataTypes.BOOLEAN;
+import static com.openexchange.usm.api.datatypes.DataTypes.DATE;
+import static com.openexchange.usm.api.datatypes.DataTypes.NUMBER;
+import static com.openexchange.usm.api.datatypes.DataTypes.NUMBER_NOT_NULL;
+import static com.openexchange.usm.api.datatypes.DataTypes.STRING;
+import static com.openexchange.usm.api.datatypes.DataTypes.TIME;
 import java.util.BitSet;
 import com.openexchange.usm.api.contenttypes.AppointmentContentType;
 import com.openexchange.usm.api.contenttypes.ContentTypeField;
