@@ -69,6 +69,7 @@ import com.openexchange.usm.api.exceptions.InternalUSMException;
 import com.openexchange.usm.api.exceptions.OXCommunicationException;
 import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.session.DataObject;
+import com.openexchange.usm.api.session.DataObjectFilter;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.contenttypes.util.AbstractTransferHandler;
@@ -119,8 +120,8 @@ public class AppointmentContentTypeTransferHandler extends AbstractTransferHandl
 	}
 
     @Override
-    public OXFolderContent readFolderContent(Folder folder, int limit) throws USMException {
-        OXFolderContent result = super.readFolderContent(folder, limit);
+    public OXFolderContent readFolderContent(Folder folder, int limit, DataObjectFilter filter) throws USMException {
+        OXFolderContent result = super.readFolderContent(folder, limit, filter);
         resetRecurrenceTypeBasedFields(result.getObjects());
         return result;
     }
