@@ -48,7 +48,11 @@
  */
 package com.openexchange.usm.contenttypes.contacts.impl;
 
-import static com.openexchange.usm.api.datatypes.DataTypes.*;
+import static com.openexchange.usm.api.datatypes.DataTypes.BOOLEAN;
+import static com.openexchange.usm.api.datatypes.DataTypes.DATE;
+import static com.openexchange.usm.api.datatypes.DataTypes.NUMBER;
+import static com.openexchange.usm.api.datatypes.DataTypes.STRING;
+import static com.openexchange.usm.api.datatypes.DataTypes.TIME;
 import java.util.BitSet;
 import java.util.List;
 import java.util.Map;
