@@ -48,6 +48,8 @@
  */
 package com.openexchange.usm.contenttypes.contacts.impl;
 
+import static com.openexchange.usm.contenttypes.util.UtilConstants.ACTION_NEW;
+import static com.openexchange.usm.contenttypes.util.UtilConstants.ACTION_UPDATE;
 import java.awt.Color;
 import java.awt.Graphics2D;
 import java.awt.image.BufferedImage;
@@ -87,6 +89,8 @@ import com.openexchange.usm.ox_json.JSONResult;
 import com.openexchange.usm.ox_json.JSONResultType;
 import com.openexchange.usm.ox_json.OXJSONAccess;
 import com.openexchange.usm.ox_json.OXResource;
+import com.openexchange.usm.util.TempFile;
+import com.openexchange.usm.util.TempFileStorage;
 import com.openexchange.usm.util.Toolkit;
 
 /**
@@ -105,9 +109,19 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 	private static final String IMAGE_COLUMNS = "597,606,601";
 	private static final String ACTION_SEARCH = "search";
 
-	public ContactContentTypeTransferHandler(ContactContentType contentType, Log log, OXJSONAccess ajaxAccess) {
-		super(contentType, log, ajaxAccess);
-	}
+    private final BitSet _image1FieldSet;
+
+    public ContactContentTypeTransferHandler(ContactContentType contentType, Log log, OXJSONAccess ajaxAccess) {
+        super(contentType, log, ajaxAccess);
+        _image1FieldSet = new BitSet();
+        ContentTypeField[] fields = contentType.getFields();
+        for (int i = 0; i < fields.length; i++) {
+            if (fields[i].getFieldID() == ContactContentTypeImpl.IMAGE1_FIELD_ID) {
+                _image1FieldSet.set(i);
+                break;
+            }
+        }
+    }
 
 	@Override
 	protected String getOXAjaxAccessPath() {
@@ -192,30 +206,42 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 
 	}
 
-	public byte[] getPictureData(DataObject dataObject, String pictureFormat, int maxSize)
-			throws AuthenticationFailedException, OXCommunicationException, PictureConversionException {
-		Image image = (Image) dataObject.getFieldContent(ImageDataType.IMAGE1);
-		if (image == null)
-			return null;
-		String url = image.getUrl();
-		if (Toolkit.isNullOrEmpty(url))
-			return null;
-		if (DECODE_IMAGE_URL) {
-			try {
-				url = URLDecoder.decode(url, "UTF-8");
-			} catch (UnsupportedEncodingException e1) {
-				return null;
-			}
-		}
-		//		String imageContentType = (String) dataObject.getFieldContent("image1_content_type");
-		OXResource sourceData = _ajaxAccess.getResource(dataObject.getSession(), url, null);
-		int sourceSize = sourceData.getData().length;
-		if (sourceSize == 0)
-			return null;
-		if (sourceData.getContentType().equalsIgnoreCase("image/" + pictureFormat) && sourceSize <= maxSize)
-			return sourceData.getData();
-		// Conversion required because picture is in the wrong format or too big
-		// The scale factor is just an estimate, since we have to scale to some target byte size in the output
+    private String getImageUrl(DataObject dataObject) {
+        try {
+            Image image = (Image) dataObject.getFieldContent(ImageDataType.IMAGE1);
+            if (image == null)
+                return null;
+            String url = image.getUrl();
+            if (!Toolkit.isNullOrEmpty(url))
+                return url;
+            readDataObject(dataObject, _image1FieldSet);
+            image = (Image) dataObject.getFieldContent(ImageDataType.IMAGE1);
+            return (image == null) ? null : image.getUrl();
+        } catch (USMException e) {
+            return null;
+        }
+    }
+
+    public byte[] getPictureData(DataObject dataObject, String pictureFormat, int maxSize) throws AuthenticationFailedException, OXCommunicationException, PictureConversionException {
+        String url = getImageUrl(dataObject);
+        if (Toolkit.isNullOrEmpty(url))
+            return null;
+        if (DECODE_IMAGE_URL) {
+            try {
+                url = URLDecoder.decode(url, "UTF-8");
+            } catch (UnsupportedEncodingException e1) {
+                return null;
+            }
+        }
+        // String imageContentType = (String) dataObject.getFieldContent("image1_content_type");
+        OXResource sourceData = _ajaxAccess.getResource(dataObject.getSession(), url, null);
+        int sourceSize = sourceData.getData().length;
+        if (sourceSize == 0)
+            return null;
+        if (sourceData.getContentType().equalsIgnoreCase("image/" + pictureFormat) && sourceSize <= maxSize)
+            return sourceData.getData();
+        // Conversion required because picture is in the wrong format or too big
+        // The scale factor is just an estimate, since we have to scale to some target byte size in the output
 		// The picture is either too big or in the wrong format, in either case we assume that if we scale to
 		// about 90% of the limit divided by its current size (if the picture is bigger than that), our result
 		// will be within the limit. We have a fall back algorithm, that halves the size up to 2 times if our
@@ -287,7 +313,7 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 	}
 
 	private boolean containsImage(Image i) {
-		return (i != null) && i.getContentType() != null && i.getContentType().length() > 0 && i.getData() != null;
+		return (i != null) && i.getContentType() != null && i.getContentType().length() > 0 && (i.getData() != null || i.getTempId() != null);
 	}
 
 	@Override
@@ -303,9 +329,14 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 			parameters.put(UtilConstants.TIMESTAMP, String.valueOf(timestamp));
 			JSONObject requestBody = createRequestBody(object, true, false);
 
-			JSONResult result = _ajaxAccess.storeResource(getOXAjaxAccessPath(), UtilConstants.ACTION_UPDATE, object
+			if(i.getData() != null) {
+			    JSONResult result = _ajaxAccess.storeResource(getOXAjaxAccessPath(), ACTION_UPDATE, object
 					.getSession(), parameters, requestBody, i.getData(), i.getContentType());
-			checkResult(result, JSONResultType.JSONObject);
+			    checkResult(result, JSONResultType.JSONObject);
+			} else {
+			    JSONResult result = storeImageFromTempFile(ACTION_UPDATE, object, i, parameters, requestBody);
+                checkResult(result, JSONResultType.JSONObject);
+			}
 			// XXX Shouldn't we use the timestamp returned from the OX server ?
 			// object.setFieldContent(ImageDataType.IMAGE1, new Image(timestamp, null, null));
 			object.setTimestamp(timestamp);
@@ -322,11 +353,16 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 		JSONResult result;
 
 		if (containsImage(i)) {
-			if (_journal.isDebugEnabled())
-				_journal.debug(object.getSession() + " New contact with picture");
-
-			result = _ajaxAccess.storeResource(getOXAjaxAccessPath(), UtilConstants.ACTION_NEW, object.getSession(),
-					parameters, requestBody, i.getData(), i.getContentType());
+		    if(i.getData() != null) {
+		        if (_journal.isDebugEnabled())
+		            _journal.debug(object.getSession() + " New contact with picture data");
+		        result = _ajaxAccess.storeResource(getOXAjaxAccessPath(), UtilConstants.ACTION_NEW, object.getSession(),
+		            parameters, requestBody, i.getData(), i.getContentType());
+		    } else {
+                if (_journal.isDebugEnabled())
+                    _journal.debug(object.getSession() + " New contact with picture tempid " + i.getTempId());
+                result = storeImageFromTempFile(ACTION_NEW, object, i, parameters, requestBody);
+		    }
 		} else {
 			if (_journal.isDebugEnabled())
 				_journal.debug(object.getSession() + " New " + _contentType.getID());
@@ -334,7 +370,7 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 			if (requestBody.has(ImageDataType.IMAGE1) && requestBody.isNull(ImageDataType.IMAGE1))
 				requestBody.remove(ImageDataType.IMAGE1);
 
-			result = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_NEW, object.getSession(),
+			result = _ajaxAccess.doPut(getOXAjaxAccessPath(), ACTION_NEW, object.getSession(),
 					parameters, requestBody);
 		}
 
@@ -349,6 +385,21 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 		}
 	}
 
+    public JSONResult storeImageFromTempFile(String action, DataObject object, Image i, Map<String, String> parameters, JSONObject requestBody) throws AuthenticationFailedException, OXCommunicationException, USMException {
+        TempFile tempFile = null;
+        try {
+            tempFile = TempFileStorage.getTempFileForRead(object.getSession(), i.getTempId());
+            return _ajaxAccess.storeResourceFromStream(getOXAjaxAccessPath(), action, object.getSession(), parameters, requestBody, i.getContentType(), tempFile.getSize(), tempFile);
+        } catch (IOException e) {
+            throw new USMException(
+                USMContentTypesContactsErrorCodes.CAN_NOT_ACCESS_TEMP_FILE_FOR_IMAGE_DATA,
+                "Can't access temp file for creating contact image with tempid '" + i.getTempId() + '\'',
+                e);
+        } finally {
+            Toolkit.close(tempFile);
+        }
+    }
+
 	@Override
 	protected void addFieldToRequestBody(DataObject object, boolean isOnlyModifiedFields,
 			boolean isIdshouldNotBePresent, JSONObject requestBody, ContentTypeField field, int fieldIndex)
