@@ -48,7 +48,12 @@
  */
 package com.openexchange.usm.contenttypes.folder.impl;
 
-import static com.openexchange.usm.api.datatypes.DataTypes.*;
+import static com.openexchange.usm.api.datatypes.DataTypes.BOOLEAN;
+import static com.openexchange.usm.api.datatypes.DataTypes.NUMBER;
+import static com.openexchange.usm.api.datatypes.DataTypes.NUMBER_NOT_NULL;
+import static com.openexchange.usm.api.datatypes.DataTypes.STRING;
+import static com.openexchange.usm.api.datatypes.DataTypes.TIME;
+import static com.openexchange.usm.api.datatypes.DataTypes.TIMESTAMP;
 import com.openexchange.usm.api.contenttypes.ContentTypeField;
 import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
 import com.openexchange.usm.api.contenttypes.FolderConstants;
