@@ -60,9 +60,9 @@ import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.usm.api.contenttypes.ContentType;
 import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
-import com.openexchange.usm.api.contenttypes.OXFolderContent;
 import com.openexchange.usm.api.contenttypes.FolderContentType;
 import com.openexchange.usm.api.contenttypes.FolderContentTypeTransferHandler;
+import com.openexchange.usm.api.contenttypes.OXFolderContent;
 import com.openexchange.usm.api.contenttypes.UnsupportedContentOperationException;
 import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
 import com.openexchange.usm.api.exceptions.FolderNotFoundException;
@@ -72,6 +72,7 @@ import com.openexchange.usm.api.exceptions.OperationDeniedException;
 import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.exceptions.USMIllegalArgumentException;
 import com.openexchange.usm.api.session.DataObject;
+import com.openexchange.usm.api.session.DataObjectFilter;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.contenttypes.util.AbstractTransferHandler;
@@ -106,7 +107,7 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
     }
 
     @Override
-    public OXFolderContent readFolderContent(Folder folder, int limit) throws USMException {
+    public OXFolderContent readFolderContent(Folder folder, int limit, DataObjectFilter filter) throws USMException {
         return new OXFolderContent(true, readFolderContent(folder, folder.getSession().getFieldFilter(folder.getContentType())));
     }
     
