@@ -48,7 +48,7 @@
  */
 package com.openexchange.usm.contenttypes.groups.impl;
 
-import static com.openexchange.usm.api.datatypes.DataTypes.*;
+import static com.openexchange.usm.api.datatypes.DataTypes.STRING;
 import com.openexchange.usm.api.contenttypes.ContentTypeField;
 import com.openexchange.usm.api.contenttypes.ContentTypeTransferHandler;
 import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
