@@ -49,7 +49,11 @@
 
 package com.openexchange.usm.contenttypes.mail.impl;
 
-import static com.openexchange.usm.api.datatypes.DataTypes.*;
+import static com.openexchange.usm.api.datatypes.DataTypes.BOOLEAN;
+import static com.openexchange.usm.api.datatypes.DataTypes.NUMBER;
+import static com.openexchange.usm.api.datatypes.DataTypes.NUMBER_NOT_NULL;
+import static com.openexchange.usm.api.datatypes.DataTypes.STRING;
+import static com.openexchange.usm.api.datatypes.DataTypes.TIME;
 import java.util.BitSet;
 import java.util.List;
 import org.json.JSONObject;
