@@ -73,6 +73,7 @@ import com.openexchange.usm.api.exceptions.USMIllegalArgumentException;
 import com.openexchange.usm.api.exceptions.USMStartupException;
 import com.openexchange.usm.api.io.InputStreamProvider;
 import com.openexchange.usm.api.session.DataObject;
+import com.openexchange.usm.api.session.DataObjectFilter;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.api.session.SyncResult;
@@ -437,7 +438,7 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
     }
 
     @Override
-    public OXFolderContent readFolderContent(Folder folder, int limit) throws USMException {
+    public OXFolderContent readFolderContent(Folder folder, int limit, DataObjectFilter filter) throws USMException {
         return new OXFolderContent(true, readFolderContent(folder, folder.getSession().getFieldFilter(folder.getElementsContentType()), limit));
     }
 
