@@ -49,8 +49,9 @@
 package com.openexchange.usm.datatypes.mail;
 
 import java.io.Serializable;
-import org.json.*;
-
+import org.json.JSONArray;
+import org.json.JSONException;
+import org.json.JSONObject;
 import com.openexchange.usm.api.datatypes.AbstractDataType;
 import com.openexchange.usm.api.session.Session;
 
