@@ -79,6 +79,7 @@ import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.exceptions.USMIllegalArgumentException;
 import com.openexchange.usm.api.session.ChangeState;
 import com.openexchange.usm.api.session.DataObject;
+import com.openexchange.usm.api.session.DataObjectFilter;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.api.session.SyncResult;
@@ -632,11 +633,11 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
     }
 
     public DataObject[] readFolderContent(Folder folder) throws USMException {
-        return readFolderContent(folder, Integer.MAX_VALUE).getObjects();
+        return readFolderContent(folder, Integer.MAX_VALUE, null).getObjects();
     }
 
-    public OXFolderContent readFolderContent(Folder folder, int limit) throws USMException {
-        return readOptimizedFolderContent(folder, limit);
+    public OXFolderContent readFolderContent(Folder folder, int limit, DataObjectFilter filter) throws USMException {
+        return readOptimizedFolderContent(folder, limit, filter);
     }
 
     public DataObject[] readFolderContent(Folder folder, BitSet requestedFields) throws USMException {
@@ -962,7 +963,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         }
     }
 
-    protected OXFolderContent readOptimizedFolderContent(Folder folder, int limit) throws USMException {
+    protected OXFolderContent readOptimizedFolderContent(Folder folder, int limit, DataObjectFilter filter) throws USMException {
         if (_journal.isDebugEnabled())
             _journal.debug(folder.getSession() + " Read all " + _contentType.getID() + " in folder " + folder.getID());
         if (CHECK_ACCESS_RIGHTS_BEFORE_FOLDER_READ && !hasFolderReadRights(folder))
@@ -973,27 +974,28 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
             requestFields.or(folder.getSession().getFieldFilter(folder.getElementsContentType()));
             DataObjectSet cachedObjects = getCachedObjects(folder);
             OXObjectIDList currentTimestamps = getCurrentTimestampsFromOX(folder);
-            
+
             // Compute objects to read from OX
-            List<String> idsToRead = new ArrayList<String>();
-            int newCount = 0;
+            List<String> changedObjects = new ArrayList<String>();
+            List<String> newObjects = new ArrayList<String>();
             for (int i = 0; i < currentTimestamps.size(); i++) {
                 String id = currentTimestamps.getID(i);
                 DataObject cachedObject = cachedObjects.get(id);
                 if (cachedObject == null) {
-                    if (newCount++ < limit)
-                        idsToRead.add(id);
+                    newObjects.add(id);
                 } else {
                     Object o = cachedObject.getFieldContent(UtilConstants.LAST_MODIFIED);
                     if (!(o instanceof Number) || ((Number) o).longValue() != currentTimestamps.getLastModified(i)) {
-                        idsToRead.add(id);
+                        changedObjects.add(id);
                     }
                 }
             }
-            DataObjectSet currentServerObjects = readObjectsFromOX(folder, idsToRead, requestFields);
+            DataObjectSet currentServerObjects = new DataObjectSet();
+            readObjectsFromOX(folder, changedObjects, requestFields, currentServerObjects, changedObjects.size(), null);
+            boolean complete = readObjectsFromOX(folder, newObjects, requestFields, currentServerObjects, limit, filter);
             DataObject[] result = mergeObjectsFromOXWithCachedObjects(currentTimestamps, cachedObjects, currentServerObjects);
             updateTimestampsAndOtherData(currentTimestamps, result);
-            return new OXFolderContent(newCount < limit, result);
+            return new OXFolderContent(complete, result);
         } catch (OXCommunicationException e) {
             // catch the OXCommunication exception and then get the access rights
             if (hasFolderReadRights(folder))
@@ -1033,19 +1035,25 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
     protected void addExtraTimestampListParameters(Map<String, String> parameters) {
     }
 
-    protected DataObjectSet readObjectsFromOX(Folder folder, List<String> objectsToRead, BitSet requestedFields) throws UnsupportedContentOperationException, AuthenticationFailedException, OXCommunicationException, InternalUSMException {
+    protected boolean readObjectsFromOX(Folder folder, List<String> objectsToRead, BitSet requestedFields, DataObjectSet result, int limit, DataObjectFilter filter) throws UnsupportedContentOperationException, AuthenticationFailedException, OXCommunicationException, InternalUSMException {
         if (objectsToRead == null || objectsToRead.isEmpty())
-            return new DataObjectSet();
-        if (objectsToRead.size() <= _MAX_OBJECTS_PER_LIST)
-            return new DataObjectSet(readSomeObjectsFromOX(folder, objectsToRead, requestedFields));
-        DataObjectSet result = new DataObjectSet();
-        for (int i = 0; i < objectsToRead.size(); i += _MAX_OBJECTS_PER_LIST) {
-            int limit = Math.min(i + _MAX_OBJECTS_PER_LIST, objectsToRead.size());
-            List<String> subList = objectsToRead.subList(i, limit);
+            return true;
+        int read = 0;
+        for (int i = 0; i < objectsToRead.size();) {
+            int upperBounds = Math.min(i + _MAX_OBJECTS_PER_LIST, objectsToRead.size());
+            List<String> subList = objectsToRead.subList(i, upperBounds);
             DataObject[] someObjects = readSomeObjectsFromOX(folder, subList, requestedFields);
-            result.addAll(someObjects);
+            for(DataObject o : someObjects) {
+                if(filter == null || filter.accept(o)) {
+                    result.add(o);
+                    read++;
+                }
+            }
+            if(read >= limit && upperBounds < objectsToRead.size())
+                return false;
+            i = upperBounds;
         }
-        return result;
+        return true;
     }
 
     protected DataObject[] readSomeObjectsFromOX(Folder folder, List<String> objectsToRead, BitSet requestedFields) throws UnsupportedContentOperationException, AuthenticationFailedException, OXCommunicationException, InternalUSMException {
