@@ -203,4 +203,12 @@ public class OXDBService implements DatabaseAccess, SQLConnectionReleaser {
                 e);
         }
     }
+    
+    public boolean supportsOnDuplicateKeyUpdateStatement() {
+        return true;
+    }
+
+    public boolean supportsInsertIgnoreStatement() {
+        return true;
+    }
 }
