@@ -48,16 +48,19 @@
  */
 package com.openexchange.usm.database.ox;
 
-import java.util.*;
-
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.List;
 import org.apache.commons.logging.Log;
 import org.osgi.service.component.ComponentContext;
-
 import com.openexchange.database.DatabaseService;
 import com.openexchange.groupware.update.UpdateTask;
 import com.openexchange.groupware.update.UpdateTaskProviderService;
 import com.openexchange.usm.api.database.DatabaseAccess;
-import com.openexchange.usm.database.ox.update.*;
+import com.openexchange.usm.database.ox.update.ChangeCollationUpdateTask;
+import com.openexchange.usm.database.ox.update.USMCreatePrimaryKeyUpdateTask;
+import com.openexchange.usm.database.ox.update.USMTablesUpdateTaskV2;
+import com.openexchange.usm.database.ox.update.USMUUIDTablesUpdateTaskV2;
 import com.openexchange.usm.journal.Journal;
 
 public class USMUpdateTaskProvider implements UpdateTaskProviderService {
