@@ -48,11 +48,15 @@
  */
 package com.openexchange.usm.database.ox.update;
 
-import java.sql.*;
-
+import java.sql.Connection;
+import java.sql.SQLException;
+import java.sql.Statement;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.update.PerformParameters;
-import com.openexchange.usm.database.ox.*;
+import com.openexchange.usm.database.ox.TableDefinition;
+import com.openexchange.usm.database.ox.USMUUIDTablesUpdateTask;
+import com.openexchange.usm.database.ox.USMUpdateExceptionCodes;
+import com.openexchange.usm.database.ox.USMUpdateTaskProvider;
 
 public class ChangeCollationUpdateTask extends USMBaseUpdateTaskV2 {
 
