@@ -49,16 +49,27 @@
 
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.CONTACT_IMAGE_DATA;
+import static com.openexchange.usm.connector.commands.CommandConstants.LENGTH;
+import static com.openexchange.usm.connector.commands.CommandConstants.MORE_AVAILABLE;
+import static com.openexchange.usm.connector.commands.CommandConstants.OFFSET;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
+import static com.openexchange.usm.connector.commands.CommandConstants.TEMPID;
 import java.io.IOException;
 import java.io.Writer;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import org.json.JSONException;
+import org.json.JSONObject;
+import com.openexchange.usm.api.contenttypes.ContactContentType;
 import com.openexchange.usm.api.contenttypes.MailContentType;
 import com.openexchange.usm.api.contenttypes.ResourceInputStream;
+import com.openexchange.usm.api.database.DatabaseAccessException;
 import com.openexchange.usm.api.exceptions.USMException;
+import com.openexchange.usm.api.exceptions.USMSQLException;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.Folder;
+import com.openexchange.usm.datatypes.contacts.Image;
 import com.openexchange.usm.json.ConnectorBundleErrorCodes;
 import com.openexchange.usm.json.ServletConstants;
 import com.openexchange.usm.json.USMJSONAPIException;
@@ -66,7 +77,8 @@ import com.openexchange.usm.json.USMJSONServlet;
 import com.openexchange.usm.json.USMJSONVersion;
 import com.openexchange.usm.json.response.ResponseObject;
 import com.openexchange.usm.json.response.ResponseStatusCode;
-import com.openexchange.usm.json.streaming.AttachmentTempId;
+import com.openexchange.usm.json.streaming.ServerTempId;
+import com.openexchange.usm.json.streaming.ServerTempIdType;
 import com.openexchange.usm.util.Toolkit;
 
 /**
@@ -103,7 +115,9 @@ public class DownloadDataHandler extends NormalCommandHandler {
 
     private boolean _moreAvailable;
 
-    private AttachmentTempId _id;
+    private ServerTempId _id;
+
+    private DataObject _object;
 
     private ResponseStatusCode _responseStatus = ResponseStatusCode.SUCCESS;
 
@@ -127,17 +141,21 @@ public class DownloadDataHandler extends NormalCommandHandler {
 
     @Override
     public ResponseObject handleRequest() throws USMJSONAPIException {
-        _id = AttachmentTempId.fromString(getStringParameter(TEMPID));
+        _id = ServerTempId.fromString(getStringParameter(TEMPID));
+        initializeDataObjectForDownload();
+        if (_id.getType() == ServerTempIdType.IMAGE)
+            return handleRequestForContactImage();
         ResourceInputStream is = getResourceInputStream();
         try {
             Writer w = null;
             try {
-                if (!_id.isPIMAttachment())
+                if (_id.getType() == ServerTempIdType.MAIL)
                     skipOffset(is);
                 _response.setContentType(ServletConstants.USM_JSON_CONTENT_TYPE);
                 _response.setContentLength(computeContentLength());
                 w = _response.getWriter();
                 writeResponse(is, w);
+                return null;
             } catch (IOException e) {
                 throw new USMJSONAPIException(
                     ConnectorBundleErrorCodes.DOWNLOAD_DATA_CAN_NOT_CREATE_RESPONSE_WRITER,
@@ -150,7 +168,34 @@ public class DownloadDataHandler extends NormalCommandHandler {
         } finally {
             Toolkit.close(is);
         }
-        return null;
+    }
+
+    private ResponseObject handleRequestForContactImage() throws USMJSONAPIException {
+        _object.setFieldContent(CONTACT_IMAGE_DATA, new Image());
+        try {
+            byte[] content = ((ContactContentType) _object.getContentType()).getPictureData(_object, "jpeg", Integer.MAX_VALUE);
+            _realLength = Math.max(0L, Math.min(_requestedLength, content.length - _offset));
+            _moreAvailable = _offset + _realLength < content.length;
+            if (content.length != _realLength) {
+                byte[] shortened = new byte[(int) _realLength];
+                if (_realLength > 0)
+                    System.arraycopy(content, (int) _offset, shortened, 0, (int) _realLength);
+                content = shortened;
+            }
+            JSONObject data = new JSONObject();
+            data.put("data", Toolkit.encodeBase64(content));
+            if (_moreAvailable)
+                data.put(MORE_AVAILABLE, true);
+            return new ResponseObject(_responseStatus, data);
+        } catch (USMException e) {
+            throw new USMJSONAPIException(
+                ConnectorBundleErrorCodes.DOWNLOAD_DATA_IMAGE_NOT_FOUND,
+                ResponseStatusCode.WRONG_MISSING_PARAMETERS,
+                "Image not found for '" + _id + '\'',
+                e);
+        } catch (JSONException e) {
+            throw USMJSONAPIException.createJSONError(ConnectorBundleErrorCodes.DOWNLOAD_DATA_JSON_ERROR, e);
+        }
     }
 
     private void skipOffset(ResourceInputStream is) throws IOException {
@@ -165,7 +210,10 @@ public class DownloadDataHandler extends NormalCommandHandler {
         w.write(_DATA_PREFIX);
         writeContent(is, w);
         w.write(_DATA_SUFFIX);
-        w.write('0' + _responseStatus.getStatusCode() / 10);
+        if (_responseStatus.getStatusCode() >= 10)
+            w.write('0' + _responseStatus.getStatusCode() / 10);
+        else
+            w.write(' ');
         w.write('0' + _responseStatus.getStatusCode() % 10);
         w.write('}');
     }
@@ -207,29 +255,46 @@ public class DownloadDataHandler extends NormalCommandHandler {
         return length;
     }
 
+    private Folder getFolderOfDataObject() throws USMJSONAPIException {
+        try {
+            return _session.getCachedFolder(_id.getFolderId());
+        } catch (DatabaseAccessException e) {
+            throw new USMJSONAPIException(
+                ConnectorBundleErrorCodes.DOWNLOAD_DATA_DB_ERROR_FOR_FOLDER,
+                ResponseStatusCode.WRONG_MISSING_PARAMETERS,
+                "DB error while accessing folder for '" + _id + '\'',
+                e);
+        } catch (USMSQLException e) {
+            throw new USMJSONAPIException(
+                ConnectorBundleErrorCodes.DOWNLOAD_DATA_SQL_ERROR_FOR_FOLDER,
+                ResponseStatusCode.INTERNAL_ERROR,
+                "SQL error while accessing folder for '" + _id + '\'',
+                e);
+        }
+    }
+
+    private void initializeDataObjectForDownload() throws USMJSONAPIException {
+        Folder folder = getFolderOfDataObject();
+        if (folder == null)
+            throw new USMJSONAPIException(
+                ConnectorBundleErrorCodes.DOWNLOAD_DATA_FOLDER_NOT_FOUND,
+                ResponseStatusCode.WRONG_MISSING_PARAMETERS,
+                "Folder not found for '" + _id + '\'');
+        _object = folder.getElementsContentType().newDataObject(_session);
+        _object.setParentFolder(folder);
+        _object.setID(_id.getObjectId());
+        checkCorrectContentType();
+    }
+
     private ResourceInputStream getResourceInputStream() throws USMJSONAPIException {
         try {
-            Folder folder = _session.getCachedFolder(_id.getFolderId());
-            if (folder == null)
-                throw new USMJSONAPIException(
-                    ConnectorBundleErrorCodes.DOWNLOAD_DATA_FOLDER_NOT_FOUND,
-                    ResponseStatusCode.WRONG_MISSING_PARAMETERS,
-                    "Folder not found for '" + _id + '\'');
-            DataObject object = folder.getElementsContentType().newDataObject(_session);
-            object.setParentFolder(folder);
-            object.setID(_id.getObjectId());
-            if (_id.isPIMAttachment() == (object.getContentType() instanceof MailContentType))
-                throw new USMJSONAPIException(
-                    ConnectorBundleErrorCodes.DOWNLOAD_DATA_INVALID_OBJECT_TYPE,
-                    ResponseStatusCode.WRONG_MISSING_PARAMETERS,
-                    "Object associated with '" + _id + "' is of wrong ContentType " + object.getContentType().getID());
             _realLength = Math.max(0L, Math.min(_requestedLength, _id.getSize() - _offset));
             _moreAvailable = _offset + _realLength < _id.getSize();
-            if (_id.isPIMAttachment()) {
+            if (_id.getType() == ServerTempIdType.PIM) {
                 int attachmentId = Integer.parseInt(_id.getAttachmentId());
-                return object.getContentType().getTransferHandler().getAttachmentDataStream(object, attachmentId, _offset, _realLength);
+                return _object.getContentType().getTransferHandler().getAttachmentDataStream(_object, attachmentId, _offset, _realLength);
             }
-            MailContentType mailContentType = (MailContentType) object.getContentType();
+            MailContentType mailContentType = (MailContentType) _object.getContentType();
             return mailContentType.getMailAttachmentAsStream(_session, _id.getFolderId(), _id.getObjectId(), _id.getAttachmentId());
         } catch (NumberFormatException ignored) {
             throw new USMJSONAPIException(
@@ -241,6 +306,29 @@ public class DownloadDataHandler extends NormalCommandHandler {
         }
     }
 
+    private void checkCorrectContentType() throws USMJSONAPIException {
+        switch (_id.getType()) {
+        case MAIL:
+            if (_object.getContentType() instanceof MailContentType)
+                return;
+            break;
+        case IMAGE:
+            if (_object.getContentType() instanceof ContactContentType)
+                return;
+            break;
+        case PIM:
+            if (!(_object.getContentType() instanceof MailContentType))
+                return;
+            break;
+        default:
+            break;
+        }
+        throw new USMJSONAPIException(
+            ConnectorBundleErrorCodes.DOWNLOAD_DATA_INVALID_OBJECT_TYPE,
+            ResponseStatusCode.WRONG_MISSING_PARAMETERS,
+            "Object associated with '" + _id + "' is of wrong ContentType " + _object.getContentType().getID());
+    }
+
     /*
      * (non-Javadoc)
      * @see com.openexchange.usm.connector.commands.BaseCommandHandler#getRequiredParameters()
