@@ -48,7 +48,10 @@
  */
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.FOLDERID;
+import static com.openexchange.usm.connector.commands.CommandConstants.OBJECTIDS;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
+import static com.openexchange.usm.connector.commands.CommandConstants.SYNCID;
 import java.util.UUID;
 import javax.servlet.http.HttpServletRequest;
 import org.json.JSONArray;
