@@ -48,8 +48,15 @@
  */
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
-import static com.openexchange.usm.json.response.ResponseObject.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.DESTINATIONFOLDERID;
+import static com.openexchange.usm.connector.commands.CommandConstants.DESTINATIONSYNCID;
+import static com.openexchange.usm.connector.commands.CommandConstants.OBJECTIDS;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
+import static com.openexchange.usm.connector.commands.CommandConstants.SOURCEFOLDERID;
+import static com.openexchange.usm.connector.commands.CommandConstants.SOURCESYNCID;
+import static com.openexchange.usm.json.response.ResponseObject.ERROR_DETAILS;
+import static com.openexchange.usm.json.response.ResponseObject.ERROR_MESSAGE;
+import static com.openexchange.usm.json.response.ResponseObject.ERROR_STATUS;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.BitSet;
@@ -190,15 +197,11 @@ public class MoveItemsHandler extends SyncCommandHandler {
                     object.setParentFolder(destinationFolder);
                     changesList.add(object);
                 } catch (DataObjectNotFoundException e) {
-                    if (_servlet.isFatalUUIDErrors())
-                        throw USMJSONAPIException.createObjectNotFoundException(e);
                     addError(uuidString, null, e, ErrorStatusCode.UNKNOWN_UUID);
                 } catch (MultipleOperationsOnDataObjectException e) {
                     addError(uuidString, e.getDataObject(), e, ErrorStatusCode.MULTIPLE_OPERATIONS_ON_SAME_UUID);
                     removeDuplicatesAndAddToError(changesList, uuidString, e);
                 } catch (InvalidUUIDException e) {
-                    if (_servlet.isFatalUUIDErrors())
-                        throw USMJSONAPIException.createInvalidUUIDException(e);
                     addError(uuidString, null, e, ErrorStatusCode.UNKNOWN_UUID);
                 }
             }
