@@ -49,7 +49,20 @@
 
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.ATTACHMENTS;
+import static com.openexchange.usm.connector.commands.CommandConstants.ATTACHMENTS_LAST_MODIFIED;
+import static com.openexchange.usm.connector.commands.CommandConstants.CHANGE_EXCEPTIONS;
+import static com.openexchange.usm.connector.commands.CommandConstants.FOLDER_ID;
+import static com.openexchange.usm.connector.commands.CommandConstants.FOLDER_UUID;
+import static com.openexchange.usm.connector.commands.CommandConstants.IMAGE1;
+import static com.openexchange.usm.connector.commands.CommandConstants.NUMBER_OF_ATTACHMENTS;
+import static com.openexchange.usm.connector.commands.CommandConstants.OBJECT_TYPE;
+import static com.openexchange.usm.connector.commands.CommandConstants.RECURRENCE_ID;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
+import static com.openexchange.usm.connector.commands.CommandConstants.TEMPID;
+import static com.openexchange.usm.connector.commands.CommandConstants.TITLE;
+import static com.openexchange.usm.connector.commands.CommandConstants.TYPE;
+import static com.openexchange.usm.connector.commands.CommandConstants.UUID_KEY;
 import java.util.BitSet;
 import java.util.Collection;
 import java.util.List;
@@ -87,7 +100,7 @@ import com.openexchange.usm.json.USMJSONServlet;
 import com.openexchange.usm.json.USMJSONVersion;
 import com.openexchange.usm.json.USMSessionCredentials;
 import com.openexchange.usm.json.response.ResponseStatusCode;
-import com.openexchange.usm.json.streaming.AttachmentTempId;
+import com.openexchange.usm.json.streaming.ServerTempId;
 import com.openexchange.usm.session.dataobject.DataObjectUtil;
 import com.openexchange.usm.util.Toolkit;
 
@@ -174,11 +187,17 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
                 if (DefaultContentTypes.MAIL_ID.equals(o.getContentType().getID()) && JSONSessionInitializer.isInternalMailField(fieldName))
                     continue;
                 if (IMAGE1.equals(fieldType.getName())) {
-                    if (v == null) {
+                    if (!(v instanceof Image)) {
                         newObject.put(IMAGE1, JSONObject.NULL);
                     } else {
-                        byte[] data = ((Image) v).getData();
-                        newObject.put(IMAGE1, (data == null) ? JSONObject.NULL : Toolkit.encodeBase64(data));
+                        Image image = (Image) v;
+                        if (image.getTempId() != null) {
+                            newObject.put(TEMPID, image.getTempId());
+                        } else if (image.getData() != null) {
+                            newObject.put(IMAGE1, Toolkit.encodeBase64(image.getData()));
+                        } else {
+                            newObject.put(IMAGE1, JSONObject.NULL);
+                        }
                     }
                 } else if (ATTACHMENTS_LAST_MODIFIED.equals(fieldName)) {
                     storeAttachmentsInJSONObject(newObject, v, convertToPIMAttachmentDataType(fieldType), o);
@@ -381,7 +400,7 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
             if (supportsAttachmentStreaming && att.getFileSize() > _servlet.getMaxInlineAttachmentSize()) {
                 JSONObject object = att.toJSONObject();
                 object.put(UUID_KEY, att.getUUID().toString());
-                object.put(CommandConstants.TEMPID, new AttachmentTempId(dataObject, att));
+                object.put(CommandConstants.TEMPID, ServerTempId.forPIMAttachment(dataObject, att));
                 array.put(object);
             } else {
                 try {
