@@ -49,7 +49,8 @@
 
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.MAIL;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
 import javax.servlet.http.HttpServletRequest;
 import org.json.JSONObject;
 import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
