@@ -48,7 +48,15 @@
  */
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.CLIENT_FIELD_PREFIX;
+import static com.openexchange.usm.connector.commands.CommandConstants.CONFLICT_RESOLUTION;
+import static com.openexchange.usm.connector.commands.CommandConstants.CUSTOM_PROPERTIES;
+import static com.openexchange.usm.connector.commands.CommandConstants.END_DATE;
+import static com.openexchange.usm.connector.commands.CommandConstants.FOLDER_TREE;
+import static com.openexchange.usm.connector.commands.CommandConstants.KEY_SIZE;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
+import static com.openexchange.usm.connector.commands.CommandConstants.START_DATE;
+import static com.openexchange.usm.connector.commands.CommandConstants.SYNC_CONTENT_TYPES;
 import java.util.BitSet;
 import javax.servlet.http.HttpServletRequest;
 import org.json.JSONArray;
