@@ -48,7 +48,12 @@
  */
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.CREATED;
+import static com.openexchange.usm.connector.commands.CommandConstants.DELETED;
+import static com.openexchange.usm.connector.commands.CommandConstants.FOLDERID;
+import static com.openexchange.usm.connector.commands.CommandConstants.MODIFIED;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
+import static com.openexchange.usm.connector.commands.CommandConstants.SYNCID;
 import javax.servlet.http.HttpServletRequest;
 import org.json.JSONException;
 import org.json.JSONObject;
