@@ -49,8 +49,11 @@
 package com.openexchange.usm.connector.commands;
 
 import static com.openexchange.usm.connector.commands.CommandConstants.*;
+import static com.openexchange.usm.json.ConnectorBundleErrorCodes.*;
+import static com.openexchange.usm.json.response.ResponseStatusCode.*;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.BitSet;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
@@ -62,6 +65,7 @@ import org.json.JSONArray;
 import org.json.JSONObject;
 import com.openexchange.usm.api.contenttypes.ContentType;
 import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.FolderConstants;
 import com.openexchange.usm.api.database.DatabaseAccessException;
 import com.openexchange.usm.api.datatypes.DataType;
 import com.openexchange.usm.api.exceptions.USMException;
@@ -116,7 +120,6 @@ public class SyncUpdateHandler extends SyncCommandHandler {
 	}
 
 	private long _syncID;
-	private SyncResult _syncResult;
 	private boolean _serverChangesMayBeAvailable;
 
 	private final List<MergeData> _mergedCreationsAndDeletions = new ArrayList<MergeData>();
@@ -146,8 +149,16 @@ public class SyncUpdateHandler extends SyncCommandHandler {
             }
             readOptionalRefreshUUIDs();
             _syncResult = computeSyncUpdate(folderUUID, _syncID, conflictResolution);
-            if (folderUUID == null) // make sure current folder hierarchy is read again if required for generating response
-                _allFolders = null;
+            if (folderUUID == null) {
+                _allFolders = null; // make sure current folder hierarchy is read again if required for generating response
+                BitSet deletedStandardFolders = getStandardFolderDeletionsFromSyncResult();
+                if(!deletedStandardFolders.isEmpty()) {
+                    String errorMessage = "The following required standard folder types are currently not available: " + deletedStandardFolders;
+                    _servlet.getJournal().warn(
+                        _session + " Aborting sync of folder hierarchy: " + errorMessage);
+                    return new ResponseObject(TEMPORARY_NOT_AVAILABLE, SYNC_UPDATE_STANDARD_FOLDERS_REMOVED_ON_SERVER, errorMessage, null, null);
+                }
+            }
             initializeErrorMap(_syncResult);
             long syncId = _syncResult.getTimestamp();
             Folder folder = null;
@@ -198,8 +209,6 @@ public class SyncUpdateHandler extends SyncCommandHandler {
                 try {
                     _refreshUUIDs.add(extractUUIDFromString(uuid));
                 } catch (InvalidUUIDException e) {
-                    if (_servlet.isFatalUUIDErrors())
-                        throw USMJSONAPIException.createInvalidUUIDException(e);
                     addError(uuid, null, e, ErrorStatusCode.UNKNOWN_UUID);
                 }
             }
@@ -305,7 +314,7 @@ public class SyncUpdateHandler extends SyncCommandHandler {
 				Arrays.sort(_folderClientChangesArray, new FolderHierarchyComparator(_folderClientChangesArray,
 						_servlet.getJournal()));
 				return _session.syncFolderChangesWithServer(syncId, _limit, null, true, conflictResolution,
-						_folderClientChangesArray);
+                    _folderClientChangesArray);
 			}
 			setFolderToSync(folderID);
 			_serverChangesMayBeAvailable = _session.needsSynchronization(_folderToSync.getID());
@@ -333,7 +342,63 @@ public class SyncUpdateHandler extends SyncCommandHandler {
 		}
 	}
 
-	private Folder[] createFolderChangesArray(long syncId) throws DatabaseAccessException, USMSQLException,
+    private BitSet getStandardFolderDeletionsFromSyncResult() {
+        BitSet deletedStandardFolders = new BitSet(); // all standard folder types that were deleted
+        BitSet createdStandardFolders = new BitSet(); // all standard folder types that were created
+        for (DataObject o : _syncResult.getChanges()) {
+            if (o.getChangeState() == ChangeState.DELETED) {
+                int standardFolderType = getRequiredStandardFolderType(o, false);
+                if (standardFolderType > 0)
+                    deletedStandardFolders.set(standardFolderType);
+            } else if (o.getChangeState() == ChangeState.CREATED) {
+                int standardFolderType = getRequiredStandardFolderType(o, false);
+                if (standardFolderType > 0)
+                    createdStandardFolders.set(standardFolderType);
+            } else if (o.getChangeState() == ChangeState.MODIFIED) {
+                int oldStandardFolderType = getRequiredStandardFolderType(o, true);
+                int newStandardFolderType = getRequiredStandardFolderType(o, false);
+                if (oldStandardFolderType != newStandardFolderType) {
+                    if (oldStandardFolderType > 0)
+                        deletedStandardFolders.set(oldStandardFolderType);
+                    if (newStandardFolderType > 0)
+                        createdStandardFolders.set(newStandardFolderType);
+                }
+            }
+        }
+        deletedStandardFolders.andNot(createdStandardFolders);
+        return deletedStandardFolders;
+    }
+
+    /**
+     * @param folder
+     * @param useOriginalContent for modifications, determine if the current or original content of the object should be used
+     * @return standard_folder_type if required standard folder, otherwise 0
+     */
+    private static int getRequiredStandardFolderType(DataObject folder, boolean useOriginalContent) {
+        Object fieldValue = useOriginalContent ? folder.getOriginalFieldContent(FolderConstants.STANDARD_FOLDER) : folder.getFieldContent(FolderConstants.STANDARD_FOLDER);
+        if (!(fieldValue instanceof Boolean) || !((Boolean) fieldValue).booleanValue())
+            return 0; // No standard folder -> not required
+        fieldValue = useOriginalContent ? folder.getOriginalFieldContent(FolderConstants.STANDARD_FOLDER_TYPE) : folder.getFieldContent(FolderConstants.STANDARD_FOLDER_TYPE);
+        if (fieldValue instanceof Number) {
+            int standardFolderType = ((Number) fieldValue).intValue();
+            switch (standardFolderType) {
+            case 1: // Task
+            case 2: // Calendar
+            case 3: // Contact
+            case 7: // Inbox
+            case 9: // Drafts
+            case 10: // Sent
+            case 11: // Spam
+            case 12: // Trash
+                return standardFolderType;
+            default:
+                break;
+            }
+        }
+        return 0;
+    }
+
+    private Folder[] createFolderChangesArray(long syncId) throws DatabaseAccessException, USMSQLException,
 			USMJSONAPIException, SlowSyncRequiredException {
 		Folder[] originalFolders = _session.getCachedFolders(syncId);
 		if (originalFolders == null)
@@ -464,18 +529,12 @@ public class SyncUpdateHandler extends SyncCommandHandler {
             try {
                 object = getDataObjectFromJSONObjectAndOriginalObjects(contentType, data, originalObjects);
             } catch (DataObjectNotFoundException e) {
-                if (_servlet.isFatalUUIDErrors())
-                    throw USMJSONAPIException.createObjectNotFoundException(e);
                 addError(uuidString, null, e, ErrorStatusCode.UNKNOWN_UUID);
                 continue;
             } catch (MultipleOperationsOnDataObjectException e) {
-                if (_servlet.isFatalUUIDErrors())
-                    throw USMJSONAPIException.createMultipleOperationsOnDataObjectException(e);
                 addError(uuidString, e.getDataObject(), e, ErrorStatusCode.MULTIPLE_OPERATIONS_ON_SAME_UUID);
                 continue;
             } catch (InvalidUUIDException e) {
-                if (_servlet.isFatalUUIDErrors())
-                    throw USMJSONAPIException.createInvalidUUIDException(e);
                 addError(uuidString, null, e, ErrorStatusCode.UNKNOWN_UUID);
                 continue;
             }
@@ -502,16 +561,10 @@ public class SyncUpdateHandler extends SyncCommandHandler {
                 if (hasNoError(object))
                     result.add(object);
             } catch (DataObjectNotFoundException e) {
-                if (_servlet.isFatalUUIDErrors())
-                    throw USMJSONAPIException.createObjectNotFoundException(e);
                 addError(uuidString, null, e, ErrorStatusCode.UNKNOWN_UUID);
             } catch (MultipleOperationsOnDataObjectException e) {
-                if (_servlet.isFatalUUIDErrors())
-                    throw USMJSONAPIException.createMultipleOperationsOnDataObjectException(e);
                 addError(uuidString, e.getDataObject(), e, ErrorStatusCode.MULTIPLE_OPERATIONS_ON_SAME_UUID);
             } catch (InvalidUUIDException e) {
-                if (_servlet.isFatalUUIDErrors())
-                    throw USMJSONAPIException.createInvalidUUIDException(e);
                 addError(uuidString, null, e, ErrorStatusCode.UNKNOWN_UUID);
             }
         }
