@@ -133,6 +133,7 @@ public interface ConnectorBundleErrorCodes {
 	int COMMAND_DUPLICATE_UUID = 0x610138;
 	int SYNC_INSUFFICIENT_DELETION_RIGHTS = 0x610139;
     int MULTIPLE_OPERATIONS_ON_SAME_UUID = 0x61013A;
+    int OX_ERROR_FOR_SERIES_EXCEPTION = 0x61013B;
 
 	int SYNC_INSUFFICIENT_CREATION_RIGHTS = 0x610140;
 	int SYNC_PIM_ATTACHMENT_CREATION_FAILED = 0x610141;
@@ -205,6 +206,7 @@ public interface ConnectorBundleErrorCodes {
 	int SYNC_UPDATE_INTERNAL_ERROR_2 = 0x610807;
 	int SYNC_UPDATE_CAN_NOT_SAVE_EMAILS_SYNC_STATE = 0x610808;
 	int SYNC_UPDATE_CAN_NOT_UPDATE_EMAIL_ON_SERVER = 0x610809;
+	int SYNC_UPDATE_STANDARD_FOLDERS_REMOVED_ON_SERVER = 0x61080A;
 
 	// 610900-6109FF: SyncEstimate error codes
 	int SYNC_ESTIMATE_INVALID_SYNCID = 0x610900;
@@ -268,7 +270,8 @@ public interface ConnectorBundleErrorCodes {
 	int INVALIDATE_OBJECTS_DB_ERROR = 0x611200;
 	int INVALIDATE_OBJECTS_SQL_ERROR = 0x611201;
 	int INVALIDATE_OBJECTS_INTERNAL_ERROR = 0x611202;
-	int INVALIDATE_OBJECTS_JSON_ERROR = 0x611202;
+	int INVALIDATE_OBJECTS_JSON_ERROR = 0x611203;
+	int INVALIDATE_OBJECTS_INTERNAL_ERROR_2 = 0x611204;
 
 	// 611300-6113FF: locateObjects error codes
 	int LOCATE_OBJECTS_DB_ERROR = 0x611300;
@@ -298,6 +301,10 @@ public interface ConnectorBundleErrorCodes {
     int DOWNLOAD_DATA_INVALID_LENGTH = 0x611514;
     int DOWNLOAD_DATA_CAN_NOT_CREATE_RESPONSE_WRITER = 0x611515;
     int DOWNLOAD_DATA_INVALID_OBJECT_TYPE = 0x611516;
+    int DOWNLOAD_DATA_DB_ERROR_FOR_FOLDER = 0x611517;
+    int DOWNLOAD_DATA_SQL_ERROR_FOR_FOLDER = 0x611518;
+    int DOWNLOAD_DATA_IMAGE_NOT_FOUND = 0x611519;
+    int DOWNLOAD_DATA_JSON_ERROR = 0x61151A;
 
     int COMMAND_UPLOAD_DATA_UTF_8_NOT_AVAILABLE = 0x611600;
     int COMMAND_UPLOAD_DATA_CANNOT_OPEN_INPUT_STREAM = 0x611601;
