@@ -49,7 +49,7 @@
 
 package com.openexchange.usm.json;
 
-import static com.openexchange.usm.json.ServletConstants.*;
+import static com.openexchange.usm.json.ServletConstants.PROTOCOL;
 import java.io.IOException;
 import java.io.OutputStreamWriter;
 import java.io.Writer;
@@ -125,8 +125,6 @@ public class USMJSONServlet extends HttpServlet {
 
     private transient int _pimAttachmentCountLimit;
 
-    private transient boolean _fatalUUIDErrors;
-
     private transient int _timefilterLimitPast;
 
     private transient int _timefilterLimitFuture;
@@ -185,10 +183,6 @@ public class USMJSONServlet extends HttpServlet {
                 ConfigurationProperties.JSON_SERVLET_PIM_ATTACHMENT_COUNT_LIMIT_PROPERTY,
                 ConfigurationProperties.JSON_SERVLET_PIM_ATTACHMENT_COUNT_LIMIT_DEFAULT,
                 false);
-            _fatalUUIDErrors = _configurationManager.getProperty(
-                ConfigurationProperties.JSON_SERVLET_FATAL_UUID_ERRORS_PROPERTY,
-                ConfigurationProperties.JSON_SERVLET_FATAL_UUID_ERRORS_DEFAULT,
-                false);
             _timefilterLimitPast = _configurationManager.getProperty(
                 ConfigurationProperties.JSON_SERVLET_TIMEFILTER_LIMIT_PAST_PROPERTY,
                 ConfigurationProperties.JSON_SERVLET_TIMEFILTER_LIMIT_PAST_DEFAULT,
@@ -509,10 +503,6 @@ public class USMJSONServlet extends HttpServlet {
         return _pimAttachmentCountLimit;
     }
 
-    public boolean isFatalUUIDErrors() {
-        return _fatalUUIDErrors;
-    }
-
     public int getTimefilterLimitPast() {
         return _timefilterLimitPast;
     }
