@@ -68,9 +68,9 @@ public final class USMJSONVersion {
     /**
      * USM JSON versions
      */
-    public static final String VERSION = "7.4.0-12";
+    public static final String VERSION = "7.4.1-5";
 
-    public static final String BUILD_NUMBER = "42c859ad4ce88c8cd0979065a9074ee66d7ba3fc- 5985";
+    public static final String BUILD_NUMBER = "c8919e9a1cd6835d759fd5dffc00a6fc1c269bd5- 6105";
 
     public static final String _CLIENT_USM_JSON_VERSION_KEY = "json.Prot.Version";
 
@@ -78,9 +78,11 @@ public final class USMJSONVersion {
 
     public static final USMJSONVersion SUPPORTS_ATTACHMENT_STREAMING = new USMJSONVersion("2.0.0");
 
+    public static final USMJSONVersion SUPPORTS_CONTACT_IMAGE_STREAMING = new USMJSONVersion("2.1.0");
+
     private static final USMJSONVersion _CURRENT_VERSION = _SUPPORTS_FILTERED_OUT_LARGE_OBJECTS_STATUS_CODE;
 
-    private static final USMJSONVersion _NEWEST_VERSION = SUPPORTS_ATTACHMENT_STREAMING;
+    private static final USMJSONVersion _NEWEST_VERSION = SUPPORTS_CONTACT_IMAGE_STREAMING;
 
     private static final List<USMJSONVersion> _supportedVersions = new ArrayList<USMJSONVersion>();
 
@@ -88,6 +90,7 @@ public final class USMJSONVersion {
         if (_supportedVersions.isEmpty()) {
             synchronized (_supportedVersions) {
                 if (_supportedVersions.isEmpty()) {
+                    _supportedVersions.add(SUPPORTS_CONTACT_IMAGE_STREAMING);
                     _supportedVersions.add(SUPPORTS_ATTACHMENT_STREAMING);
                     _supportedVersions.add(_SUPPORTS_FILTERED_OUT_LARGE_OBJECTS_STATUS_CODE);
                 }
@@ -107,6 +110,10 @@ public final class USMJSONVersion {
     public static Version getMatchingVersion(Version version) {
         if (version == null)
             return getCurrentVersion();
+        for (USMJSONVersion v : getSupportedVersions()) {
+            if (v.matches(version))
+                return v.getVersion();
+        }
         for (USMJSONVersion v : getSupportedVersions()) {
             if (v.supports(version))
                 return v.getVersion();
@@ -134,6 +141,10 @@ public final class USMJSONVersion {
         return !getUsedVersion(session).isOlder(SUPPORTS_ATTACHMENT_STREAMING.getVersion(), 3);
     }
 
+    public static boolean supportsContactImageStreaming(Session session) {
+        return !getUsedVersion(session).isOlder(SUPPORTS_CONTACT_IMAGE_STREAMING.getVersion(), 3);
+    }
+
     public static Version getUsedVersion(Session session) {
         return Version.fromString(session.getPersistentField(_CLIENT_USM_JSON_VERSION_KEY));
     }
@@ -148,6 +159,10 @@ public final class USMJSONVersion {
         return _version;
     }
 
+    private boolean matches(Version requestedVersion) {
+        return requestedVersion.getMajor() == _version.getMajor() && requestedVersion.getMinor() == _version.getMinor();
+    }
+
     private boolean supports(Version requestedVersion) {
         return requestedVersion.getMajor() == _version.getMajor() && requestedVersion.getMinor() <= _version.getMinor();
     }
