@@ -377,8 +377,8 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         return executeMethodAndExtractResult(session, data, method, action, parameters);
     }
 
-    public void activate(Log log, String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean passHostHeaderFromClient) {
-        String error = doActivate(log, oxJSONURL, maxConnections, connectionTimeout, performStaleChecking, passHostHeaderFromClient);
+    public void activate(Log log, String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean passHostHeaderFromClient, String reloginErrorCodes) {
+        String error = doActivate(log, oxJSONURL, maxConnections, connectionTimeout, performStaleChecking, passHostHeaderFromClient, reloginErrorCodes);
         if (error != null) {
             error = "OXJSONAccess not activated, reason: " + error;
             log.error(error);
@@ -391,7 +391,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         deactivate("USM OXJSONAccess deactivated");
     }
 
-    private String doActivate(Log log, String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean passHostHeaderFromClient) {
+    private String doActivate(Log log, String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean passHostHeaderFromClient, String reloginErrorCodes) {
         _journal = log;
         _oxJSONBaseURLasString = oxJSONURL;
         _passClientHostHeader = passHostHeaderFromClient;
@@ -400,6 +400,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         } catch (URIException e) {
             return "OXJSONAccess base URL is no valid http(s) URL: " + _oxJSONBaseURLasString;
         }
+        OXJSONSupport.setReloginErrorCodes(reloginErrorCodes);
         _connectionTimeout = connectionTimeout;
         _httpManager = new MultiThreadedHttpConnectionManager();
         HttpConnectionManagerParams httpParams = _httpManager.getParams();
@@ -494,7 +495,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         try {
             JSONResult result = executeMethodOnce(session, data.getHttpClient(), method);
             // On specific error for expired/unknown session, do login and repeat
-            if (shouldPerformNewLogin(result)) {
+            if (OXJSONSupport.shouldPerformNewLogin(result)) {
                 if (_journal.isDebugEnabled())
                     _journal.debug(session + " Session with sessionid " + data.getSessionID() + " unknown to OX server, performing login and repeat");
                 login(session);
@@ -560,13 +561,6 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         return result.getResultType() == JSONResultType.Error && OXJSONSupport.ERROR_CODE_OBJECT_CHANGED.equals(OXJSONSupport.getJSONErrorCode(result.getJSONObject()));
     }
 
-    private static boolean shouldPerformNewLogin(JSONResult result) {
-        if (result.getResultType() != JSONResultType.Error)
-            return false;
-        String errorCode = OXJSONSupport.getJSONErrorCode(result.getJSONObject());
-        return OXJSONSupport.ERROR_CODE_UNKNOWN_SESSION.equals(errorCode) || OXJSONSupport.ERROR_CODE_EXPIRED_SESSION.equals(errorCode);
-    }
-
     private static boolean shouldRetryRequest(JSONResult result) {
         if (result.getResultType() != JSONResultType.Error)
             return false;
@@ -672,6 +666,10 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         return storeResource(path, action, session, parameters, jsonData, imageByteData, fileContentType, STRING_PART_NAME, FILE_PART_NAME);
     }
 
+    public JSONResult storeResourceFromStream(String path, String action, Session session, Map<String, String> parameters, JSONObject jsonData, String fileContentType, final long size, final InputStreamProvider streamProvider) throws AuthenticationFailedException, OXCommunicationException {
+        return storeResourceFromStream(path, action, session, parameters, jsonData, fileContentType, STRING_PART_NAME, FILE_PART_NAME, size, streamProvider);
+    }
+
     public JSONResult storeResource(String path, String action, Session session, Map<String, String> parameters, JSONObject jsonData, byte[] imageByteData, String fileContentType, String jsonPartName, String filePartName) throws AuthenticationFailedException, OXCommunicationException {
         ByteArrayPartSource source = new ByteArrayPartSource(filePartName, imageByteData);
         return storeResource(path, action, session, parameters, jsonData, fileContentType, jsonPartName, filePartName, source);
