@@ -117,6 +117,10 @@ public class OXJSONErrorCode {
 
     public final static int ACCESSIMPL_TOO_MANY_DOWN_OR_BUSY_RETRIES = 0x180026;
 
+    public static final int ACCESSIMPL_CAN_NOT_READ_RESOURCE = 0x180027;
+
+    public static final int ACCESSIMPL_CAN_NOT_OPEN_RESOURCE = 0x180028;
+
     public final static int CONFIGURATION_ERROR = 0x180030;
 
     public static final int FAILED_TO_GAIN_EXCLUSIVE_OX_ACCESS = 0x180031;
