@@ -50,6 +50,8 @@
 package com.openexchange.usm.ox_json.impl;
 
 import java.io.IOException;
+import java.util.HashSet;
+import java.util.Set;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -73,10 +75,6 @@ public class OXJSONSupport {
 
     public static final String ERROR_CODE_OBJECT_CHANGED = "FLD-0001";
 
-    public static final String ERROR_CODE_UNKNOWN_SESSION = "SES-0202";
-
-    public static final String ERROR_CODE_EXPIRED_SESSION = "SES-0203";
-
     public static final String ERROR_CODE_FOLDER_MUST_NOT_BE_DELETED = "FLD-0090";
 
     public static final String ERROR_FIELD = "error";
@@ -87,6 +85,8 @@ public class OXJSONSupport {
 
     public static final String UNKNOWN_ERROR_CODE = "unknown";
 
+    private static final Set<String> _RELOGIN_ERROR_CODES = new HashSet<String>();
+
     public static JSONResult parseResult(String content, JSONResultType expectedResultType) throws IOException {
         JSONTokener tokener = new JSONTokener(content);
         try {
@@ -180,4 +180,17 @@ public class OXJSONSupport {
     private static boolean isValidResultType(JSONResultType expected, JSONResultType actual) {
         return expected == null || expected == actual;
     }
+
+    public static void setReloginErrorCodes(String reloginErrorCodes) {
+        _RELOGIN_ERROR_CODES.clear();
+        for (String s : reloginErrorCodes.split(",")) {
+            String code = s.trim();
+            if (code.length() > 0)
+                _RELOGIN_ERROR_CODES.add(code);
+        }
+    }
+
+    public static boolean shouldPerformNewLogin(JSONResult result) {
+        return result.getResultType() == JSONResultType.Error && _RELOGIN_ERROR_CODES.contains(OXJSONSupport.getJSONErrorCode(result.getJSONObject()));
+    }
 }
