@@ -48,7 +48,6 @@
  */
 package com.openexchange.usm.ox_json;
 
-import java.io.IOException;
 import java.util.Map;
 import org.apache.commons.httpclient.MultiThreadedHttpConnectionManager;
 import org.json.JSONArray;
@@ -232,6 +231,10 @@ public interface OXJSONAccess {
 			JSONObject jsonData, byte[] data, String fileContentType, String jsonPartName, String filePartName)
 			throws AuthenticationFailedException, OXCommunicationException;
 
+    JSONResult storeResourceFromStream(String path, String action, Session session, Map<String, String> parameters,
+            JSONObject jsonData, String fileContentType, long size, InputStreamProvider streamProvider)
+            throws AuthenticationFailedException, OXCommunicationException;
+
     JSONResult storeResourceFromStream(String path, String action, Session session, Map<String, String> parameters,
             JSONObject jsonData, String fileContentType, String jsonPartName, String filePartName, long size, InputStreamProvider streamProvider)
             throws AuthenticationFailedException, OXCommunicationException;
