@@ -52,6 +52,7 @@ package com.openexchange.usm.session.dataobject;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
+import java.util.UUID;
 import com.openexchange.usm.api.contenttypes.ContentType;
 import com.openexchange.usm.api.datatypes.DataType;
 import com.openexchange.usm.api.session.DataObject;
@@ -78,6 +79,26 @@ public class DataObjectUtil {
         return null;
     }
 
+    public static DataObject findDataObject(UUID uuid, DataObject... objects) {
+        if (uuid != null && objects != null) {
+            for (DataObject o : objects) {
+                if (uuid.equals(o.getUUID()))
+                    return o;
+            }
+        }
+        return null;
+    }
+
+    public static DataObject findDataObject(UUID uuid, Collection<DataObject> objects) {
+        if (uuid != null && objects != null) {
+            for (DataObject o : objects) {
+                if (uuid.equals(o.getUUID()))
+                    return o;
+            }
+        }
+        return null;
+    }
+
     public static void modify(DataObject object, DataObject modification) {
         modify(object, modification, false);
     }
