@@ -66,6 +66,7 @@ import org.json.JSONObject;
 import com.openexchange.usm.api.contenttypes.ContentType;
 import com.openexchange.usm.api.contenttypes.ContentTypeField;
 import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
+import com.openexchange.usm.api.database.DatabaseAccess;
 import com.openexchange.usm.api.database.DatabaseAccessException;
 import com.openexchange.usm.api.database.EncapsulatedConnection;
 import com.openexchange.usm.api.exceptions.USMException;
@@ -504,9 +505,35 @@ public class PersistentSessionData implements Serializable {
     }
 
     private boolean readPersistentData(SessionManagerImpl manager, Map<ContentType, BitSet> contentTypeFilter, Map<String, String> fields) throws DatabaseAccessException, USMSQLException {
+        boolean hadFields = true;
         EncapsulatedConnection con = _session.getReadOnlyDBConnection();
+        try {
+            int sessionId = readSessionIdFromDB(con);
+            if(sessionId == 0) {
+                con.close();
+                con = null;
+                con = _session.getWritableDBConnection();
+                createSessionInDB(con);
+                hadFields = false;
+                sessionId = readSessionIdFromDB(con); // re-read session id because create might have failed due to creation by someone else
+                if(sessionId == 0)
+                    throw new SQLException("USM session id could not be read after creation of USM session");
+            }
+            _session.setUniqueSessionID(sessionId);
+            // read already existing fields
+            readFieldsFromDB(con, manager, contentTypeFilter, fields);
+            _lastUpdateFromDB = System.currentTimeMillis();
+        } catch (SQLException e) {
+            String errorMessage = _session + " SQL error while retrieving persistent data from DB";
+            throw new USMSQLException(USMSessionManagementErrorCodes.PERSISTENT_SESSION_ERROR_NUMBER1, errorMessage, e);
+        } finally {
+            Toolkit.close(con);
+        }
+        return hadFields;
+    }
+
+    private int readSessionIdFromDB(EncapsulatedConnection con) throws SQLException {
         PreparedStatement statement = null;
-        boolean hadFields = false;
         try {
             statement = con.prepareStatement("select usmSessionId from USMSession where " + PersistentSessionDataSQLStatements.UNIQUE_SESSION_LONG_IDENTIFIER);
 
@@ -516,55 +543,50 @@ public class PersistentSessionData implements Serializable {
             statement.setString(4, _session.getProtocol());
 
             ResultSet result = statement.executeQuery();
-            if (result.next()) {
-                hadFields = true;
-                // the session was existing
-                int sessionId = result.getInt(1);
-                statement.close();
-                // initialize eventually existing fields
-                statement = con.prepareStatement("select Field, Value from USMSessionFields where " + PersistentSessionDataSQLStatements.UNIQUE_SESSION_IDENTIFIER);
+            if (!result.next())
+                return 0;
+            // the session was existing
+            return result.getInt(1);
+        } finally {
+            Toolkit.close(statement);
+        }
+    }
 
-                _session.setUniqueSessionID(sessionId);
-                addSessionIdenifierParamsToStatement(statement);
-                result = statement.executeQuery();
+    private void readFieldsFromDB(EncapsulatedConnection con, SessionManagerImpl manager, Map<ContentType, BitSet> contentTypeFilter, Map<String, String> fields) throws SQLException {
+        PreparedStatement statement = null;
+        try {
+            statement = con.prepareStatement("select Field, Value from USMSessionFields where " + PersistentSessionDataSQLStatements.UNIQUE_SESSION_IDENTIFIER);
+            addSessionIdenifierParamsToStatement(statement);
+            ResultSet result = statement.executeQuery();
 
-                while (result.next()) {
-                    String field = result.getString(1);
-                    String value = result.getString(2);
-                    readPersistentEntry(manager, contentTypeFilter, fields, field, value);
-                }
+            while (result.next()) {
+                String field = result.getString(1);
+                String value = result.getString(2);
+                readPersistentEntry(manager, contentTypeFilter, fields, field, value);
+            }
+        } finally {
+            Toolkit.close(statement);
+        }
+    }
 
-            } else {
-                // the session was not existing in the db
-                statement.close();
-                statement = null;
-                con.close();
-                con = null;
-                con = _session.getWritableDBConnection();
-                int sessionId = _session.getSessionManager().getDatabaseAccess().getNextIdFromSequence(
-                    _session.getContextId(),
-                    PersistentSessionDataSQLStatements.SEQUENCE_TABLE_NAME);
-                statement = con.prepareStatement("insert into USMSession (cid, id, device, protocol, usmSessionId) values(?,?,?,?,?)");
-                statement.setInt(1, _session.getContextId());
-                statement.setInt(2, _session.getUserIdentifier());
-                statement.setString(3, _session.getDevice());
-                statement.setString(4, _session.getProtocol());
-                statement.setInt(5, sessionId);
-                if (statement.executeUpdate() != 1) {
-                    throw new SQLException(
-                        _session + " Inserting session for user " + _session.getUserIdentifier() + " in DB did not change any rows");
-                }
-                _session.setUniqueSessionID(sessionId);
-            }
-            _lastUpdateFromDB = System.currentTimeMillis();
-        } catch (SQLException e) {
-            String errorMessage = _session + " SQL error while retrieving persistent data from DB";
-            throw new USMSQLException(USMSessionManagementErrorCodes.PERSISTENT_SESSION_ERROR_NUMBER1, errorMessage, e);
+    private void createSessionInDB(EncapsulatedConnection con) throws USMSQLException, DatabaseAccessException, SQLException {
+        DatabaseAccess databaseAccess = _session.getSessionManager().getDatabaseAccess();
+        int sessionId = databaseAccess.getNextIdFromSequence(
+            _session.getContextId(),
+            PersistentSessionDataSQLStatements.SEQUENCE_TABLE_NAME);
+        PreparedStatement statement = null;
+        try {
+            String insert = databaseAccess.supportsInsertIgnoreStatement() ? "insert ignore into USMSession (cid, id, device, protocol, usmSessionId) values(?,?,?,?,?)" : "insert into USMSession (cid, id, device, protocol, usmSessionId) values(?,?,?,?,?)";
+            statement = con.prepareStatement(insert);
+            statement.setInt(1, _session.getContextId());
+            statement.setInt(2, _session.getUserIdentifier());
+            statement.setString(3, _session.getDevice());
+            statement.setString(4, _session.getProtocol());
+            statement.setInt(5, sessionId);
+            statement.executeUpdate();
         } finally {
             Toolkit.close(statement);
-            Toolkit.close(con);
         }
-        return hadFields;
     }
 
     private void readPersistentEntry(SessionManagerImpl manager, Map<ContentType, BitSet> contentTypeFilter, Map<String, String> fieldMap, String field, String value) {
