@@ -97,6 +97,7 @@ import com.openexchange.usm.api.session.SessionID;
 import com.openexchange.usm.api.session.SessionInitializer;
 import com.openexchange.usm.api.session.SyncResult;
 import com.openexchange.usm.api.session.UserID;
+import com.openexchange.usm.journal.Journal;
 import com.openexchange.usm.mapping.FolderIdMapping;
 import com.openexchange.usm.ox_json.JSONResult;
 import com.openexchange.usm.ox_json.JSONResultType;
@@ -589,15 +590,16 @@ public class SessionImpl implements Session, Serializable {
         return null;
     }
 
-    public long storeCachedFolders(long oldTimestamp, long timestamp, DataObjectSet objects, boolean updatesPending) throws DatabaseAccessException, USMSQLException {
+    public long storeCachedFolders(long oldTimestamp, long timestamp, DataObjectSet objects, boolean updatesPending, long syncStartTimestamp) throws USMException {
+        checkIfObjectsAreFolders(objects.toArray());
         long result = internalStoreCachedDataObjects(FOLDER_HIERARCHY_ID, oldTimestamp, timestamp, objects);
         if (!updatesPending)
-            _lastFolderSync = result;
+            _lastFolderSync = (syncStartTimestamp == 0L) ? result : syncStartTimestamp;
         return result;
     }
-    
-  
-    public long storeCachedDataObjects(String folderID, long oldTimestamp, long timestamp, DataObjectSet objects,  boolean updatesPending) throws DatabaseAccessException, USMSQLException {
+
+    public long storeCachedDataObjects(String folderID, long oldTimestamp, long timestamp, DataObjectSet objects, boolean updatesPending) throws USMException {
+       checkValidObjectsForSyncState(folderID, objects.toArray());
         long result = internalStoreCachedDataObjects(getShortFolderID(folderID), oldTimestamp, timestamp, objects);
         if (updatesPending)
             _syncedFolderContent.remove(folderID);
@@ -607,8 +609,6 @@ public class SessionImpl implements Session, Serializable {
     }
 
     private long internalStoreCachedDataObjects(String folderID, long oldTimestamp, long timestamp, DataObjectSet objects) throws DatabaseAccessException, USMSQLException {
-        if (!_sessionManager.isKeepLastSentSyncStateInDB())
-            oldTimestamp = 0L;
         long resultingTimestamp = _syncStateStorage.put(folderID, timestamp, objects, oldTimestamp, this);
         if (resultingTimestamp != timestamp) {
             for (DataObject o : objects) {
@@ -668,7 +668,7 @@ public class SessionImpl implements Session, Serializable {
                 resultMap);
             _sessionManager.getOXDataCache().removeCachedData(_folderHierarchyCacheID);
             if (newTimestamp != 0) {
-                long modifiedTimestamp = storeCachedFolders(timestamp, newTimestamp, newFolderHierarchy, true);
+                long modifiedTimestamp = storeCachedFolders(timestamp, newTimestamp, newFolderHierarchy, true, 0L);
                 for (DataObject folder : folderChanges)
                     folder.setTimestamp(modifiedTimestamp);
             }
@@ -898,22 +898,24 @@ public class SessionImpl implements Session, Serializable {
         }
         for (String id : folderIds) {
             if (null != id) {
-             journal.debug("Removing folder from sync folder content, " + id);
-             _syncedFolderContent.remove(id);
-             _sessionManager.getOXDataCache().removeCachedData(new OXDataCacheID(this, id));
-             if ("1".equals(id)) { // for Remote Events when folderID == 1, it means that the default inbox has been changed
-                 if (journal.isDebugEnabled())
-                     journal.debug("Removing default inbox from sync folder content, " + _defaultInboxId);
-                 _syncedFolderContent.remove(_defaultInboxId);
-                 _sessionManager.getOXDataCache().removeCachedData(new OXDataCacheID(this, _defaultInboxId));
-             }
+                journal.debug("Removing folder from sync folder content, " + id);
+                _syncedFolderContent.remove(id);
+                _sessionManager.getOXDataCache().removeCachedData(new OXDataCacheID(this, id));
+                if ("1".equals(id)) { // for Remote Events when folderID == 1, it means that the default inbox has been changed
+                    if (_defaultInboxId != null) {
+                        if (journal.isDebugEnabled())
+                            journal.debug("Removing default inbox from sync folder content, " + _defaultInboxId);
+                        _syncedFolderContent.remove(_defaultInboxId);
+                        _sessionManager.getOXDataCache().removeCachedData(new OXDataCacheID(this, _defaultInboxId));
+                    }
+                }
             }
         }
         synchronized (_waitObject) {
             _waitObject.notifyAll();
         }
     }
-
+    
     public boolean needsSynchronization(String folderID) {
         return Toolkit.provided(folderID) ? !_syncedFolderContent.containsKey(folderID) : isFolderHierarchySynchronized();
     }
@@ -1214,29 +1216,45 @@ public class SessionImpl implements Session, Serializable {
     }
 
     public long storeSyncState(long timestampToKeep, long timestamp, String folderID, DataObject[] objects) throws USMException {
+        DataObjectSet set = checkValidObjectsForSyncState(folderID, objects);
+        _sessionManager.getOXDataCache().removeCachedData(new OXDataCacheID(this, folderID));
+        return storeCachedDataObjects(folderID, timestampToKeep, timestamp, set, false);
+    }
+
+    private DataObjectSet checkValidObjectsForSyncState(String folderID, DataObject[] objects) throws USMException {
         DataObjectSet set = new DataObjectSet();
         ContentType t = null;
         for (DataObject o : objects) {
             if (t == null)
                 t = o.getContentType();
-            else if (!o.getContentType().getID().equals(t.getID()))
-                throw new IllegalArgumentException("DataObjects of different ContentTypes");
-            if (!folderID.equals(o.getParentFolderID()))
-                throw new IllegalArgumentException("DataObjects of different folders");
+            else if (!o.getContentType().getID().equals(t.getID())) {
+                throw new USMException(USMSessionManagementErrorCodes.ILLEGAL_OBJETCS_TO_BE_SAVED_IN_SYNC_STATE, "DataObjects of different ContentTypes");
+            }
+            if (o.getContentType().getCode() != DefaultContentTypes.RESOURCES_CODE 
+                && o.getContentType().getCode() != DefaultContentTypes.GROUPS_CODE
+                && !folderID.equals(o.getParentFolderID())) {
+                if (_sessionManager.getJournal().isDebugEnabled())
+                    _sessionManager.getJournal().debug("The DataObject with ID: " + o.getID() + " and UUID: " + o.getUUID() 
+                            + " is a child of " + o.getParentFolderID() + " instead of " +  folderID);
+                throw new USMException(USMSessionManagementErrorCodes.ILLEGAL_OBJETCS_TO_BE_SAVED_IN_SYNC_STATE, "DataObjects of different folders");
+            }
             set.add(o);
         }
-        _sessionManager.getOXDataCache().removeCachedData(new OXDataCacheID(this, folderID));
-        return storeCachedDataObjects(folderID, timestampToKeep, timestamp, set, false);
+        return set;
     }
 
     public long storeSyncState(long timestampToKeep, long timestamp, DataObject[] objects) throws USMException {
-        for (DataObject o : objects) {
-            if (o.getContentType().getCode() != DefaultContentTypes.FOLDER_CODE)
-                throw new IllegalArgumentException("DataObjects are not folders");
-        }
+        checkIfObjectsAreFolders(objects);
         _sessionManager.getOXDataCache().removeCachedData(_folderHierarchyCacheID);
         DataObjectSet set = new DataObjectSet(objects);
-        return storeCachedFolders(timestampToKeep, timestamp, set, false);
+        return storeCachedFolders(timestampToKeep, timestamp, set, false, 0L);
+    }
+
+    private void checkIfObjectsAreFolders(DataObject[] objects) throws USMException {
+        for (DataObject o : objects) {
+            if (o.getContentType().getCode() != DefaultContentTypes.FOLDER_CODE)
+                throw new USMException(USMSessionManagementErrorCodes.ILLEGAL_OBJETCS_TO_BE_SAVED_IN_SYNC_STATE, "DataObjects are not folders");
+        }
     }
 
     public void endSyncronization() throws USMSQLException, DatabaseAccessException {
@@ -1404,11 +1422,11 @@ public class SessionImpl implements Session, Serializable {
     }
 
     public String tryLock(String id, String acquirer) {
-        return SynchronizationLock.lock(this, id, acquirer);
+        return SynchronizationLock.lock(_completeSessionID.getSessionID(), id, acquirer);
     }
 
     public void unlock(String id) {
-        SynchronizationLock.unlock(this, id);
+        SynchronizationLock.unlock(_completeSessionID.getSessionID(), id);
     }
     
     public SessionInitializer getSessionInitializer() {
