@@ -104,6 +104,7 @@ import com.openexchange.usm.session.impl.cache.MemorySyncStateCacheProvider;
 import com.openexchange.usm.session.sync.IncrementalContentSyncer;
 import com.openexchange.usm.session.sync.OXDataCache;
 import com.openexchange.usm.session.sync.SlowContentSyncer;
+import com.openexchange.usm.session.sync.SynchronizationLock;
 import com.openexchange.usm.util.JSONToolkit;
 import com.openexchange.usm.util.TempFileStorage;
 import com.openexchange.usm.util.Toolkit;
@@ -120,10 +121,14 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
 
     // private final static long SESSION_CACHE_CHECK_INTERVAL = 5000L;
 
-    private final static long ONE_DAY_IN_MILLISECONDS = 24L * 60L * 60L * 1000L;
+    private final static long ONE_HOUR_IN_MILLISECONDS = 24L * 60L * 60L * 1000L;
+
+    private final static long ONE_DAY_IN_MILLISECONDS = 24L * ONE_HOUR_IN_MILLISECONDS;
 
     public static final String LAST_ACCESS_FIELD_NAME = "USM_ACCESS";
 
+    private static final long LAST_ACCESS_UPDATE_INTERVAL = 3L * ONE_HOUR_IN_MILLISECONDS;
+
     public final static List<String> SPECIAL_FOLDERS = new ArrayList<String>();
 
     private final static List<String> SPECIAL_FOLDERS_VIEW = Collections.unmodifiableList(SPECIAL_FOLDERS);
@@ -172,8 +177,6 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
 
     private int _maxObjectsPerFolder = ConfigurationProperties.OBJECTS_IN_FOLDER_SYNC_LIMIT_DEFAULT;
 
-    private boolean _keepLastSentSyncStateInDB = ConfigurationProperties.SYNC_KEEP_LAST_SENT_STATE_IN_DB_DEFAULT;
-
     private long _sessionStorageTimeLimit = ConfigurationProperties.USM_SESSION_STORAGE_TIME_LIMIT_DEFAULT * ONE_DAY_IN_MILLISECONDS;
 
     private TimerService _timerService;
@@ -186,8 +189,6 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
 
     private int _syncRetryCount;
 
-    private boolean _forceNewSyncKeyOnEmptySync;
-
     private int _sessionCacheTimeout;
 
     private int _syncStateCacheTimeout;
@@ -251,17 +252,6 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
                 "Configuration for max_states_in_db is invalid",
                 e);
         }
-        try {
-            _keepLastSentSyncStateInDB = _configurationManager.getProperty(
-                ConfigurationProperties.SYNC_KEEP_LAST_SENT_STATE_IN_DB_PROPERTY,
-                ConfigurationProperties.SYNC_KEEP_LAST_SENT_STATE_IN_DB_DEFAULT,
-                false);
-        } catch (USMInvalidConfigurationException e) {
-            throw new USMStartupException(
-                USMSessionManagementErrorCodes.CONFIGURATION_ERROR_7,
-                "Configuration for keep_last_state_in_db is invalid",
-                e);
-        }
 
         try {
             _usmInterface = _configurationManager.getProperty(
@@ -311,18 +301,6 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
                 "Invalid configuration for " + ConfigurationProperties.SYNC_CACHE_TIME_LIMIT_INCOMPLETE_PROPERTY,
                 e);
         }
-
-        try {
-            _forceNewSyncKeyOnEmptySync = _configurationManager.getProperty(
-                ConfigurationProperties.USM_FORCE_NEW_SYNC_KEY_ON_EMPTY_SYNC,
-                ConfigurationProperties.USM_FORCE_NEW_SYNC_KEY_ON_EMPTY_SYNC_DEFAULT,
-                false);
-        } catch (USMInvalidConfigurationException e) {
-            throw new USMStartupException(
-                USMSessionManagementErrorCodes.CONFIGURATION_ERROR_13,
-                "Invalid configuration for " + ConfigurationProperties.USM_FORCE_NEW_SYNC_KEY_ON_EMPTY_SYNC,
-                e);
-        }
         try {
             _sessionCacheTimeout = _configurationManager.getProperty(
                 ConfigurationProperties.USM_CACHE_SESSION_TIMEOUT_PROPERTY,
@@ -394,6 +372,18 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
                 e);
         }
 
+        try {
+            SynchronizationLock.setLockTimeout(_configurationManager.getProperty(
+                ConfigurationProperties.SYNC_LOCK_TIMEOUT_PROPERTY,
+                ConfigurationProperties.SYNC_LOCK_TIMEOUT_DEFAULT,
+                false));
+        } catch (USMInvalidConfigurationException e) {
+            throw new USMStartupException(
+                USMSessionManagementErrorCodes.CONFIGURATION_ERROR_20,
+                "Invalid configuration for " + ConfigurationProperties.SYNC_LOCK_TIMEOUT_PROPERTY,
+                e);
+        }
+
         _sessionStorage = new SessionStorage(this);
         _dataCache = new OXDataCache(cacheTimeLimitSyncComplete, cacheTimeLimitSyncIncomplete);
         _oxEventManager.addEventListener(this);
@@ -429,40 +419,43 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         return getSession(user, password, protocol, device, null, "127.0.0.1", new HashMap<String, String>());
     }
 
-    // FIXME This code must be modified to use a more efficient approach. Iterating over all context ids takes way too long for large
-    // installations (e.g. 2 mio contexts)
-    // FIXME E.g. first check if USM session exists in memory and determine context id from it. if it doesn't exist in memory, try to login
-    // to OX server, and determine
-    // FIXME context id after login was successful. Finally, perform database check only on previously determined context id
-    public boolean existsSessionInDB(String user, String protocol, String device) throws USMException {
+    /*
+     * Optimized code. Does not iterate over all contexts anymore. Instead, the code first 
+     * looks up in the cache for the USM session. If it's not there then tries to login and 
+     * determine the context id from the retrieved session. Finally it performs a database
+     * check only on the previously determined context id.
+     */
+    // TODO This method is only called by 1 special handler. We may need to talk to the Outlook-Addin-developer(s) if the special
+    // error that is reported if the session is not known to USM is really required. If not, we could remove this code
+    public boolean existsSessionInDB(String user, String password, String protocol, String device) throws USMException {
         SessionID id = new SessionID(user, protocol, device);
         SessionImpl session = _sessionStorage.getSession(id);
         if (session != null)
             return session.checkProperDBStorage();
-
-        List<Integer> contextIds = _databaseAccess.getAllContextIds();
-        for (Integer contextId : contextIds) {
-            EncapsulatedConnection con = _databaseAccess.getReadOnly(contextId);
-            PreparedStatement statement = null;
-            boolean sessionFound = false;
-            try {
-                statement = con.prepareStatement("select usmSessionId from USMSession where " + PersistentSessionDataSQLStatements.DEVICE_IN_CONTEXT);
-                statement.setInt(1, contextId);
-                statement.setString(2, device);
-                statement.setString(3, protocol);
-                ResultSet result = statement.executeQuery();
-                sessionFound = result.next();
-            } catch (SQLException e) {
-                String errorMessage = " SQL error while retrieving session from DB";
-                throw new USMSQLException(USMSessionManagementErrorCodes.PERSISTENT_SESSION_DB_ERROR_2, errorMessage, e);
-            } finally {
-                Toolkit.close(statement);
-                Toolkit.close(con);
-            }
-            if (sessionFound)
-                return true;
+        
+        // FIXME getSession() already creates the session in the DB if it hasn't existed yet. So existsSessionInDB() will now always return true (and the code following the getSession() will always find the session in the DB)
+        session = (SessionImpl) getSession(user, password, protocol, device);
+        
+        int contextId = session.getContextId();
+        EncapsulatedConnection con = _databaseAccess.getReadOnly(contextId);
+        PreparedStatement statement = null;
+        boolean sessionFound = false;
+        try {
+            statement = con.prepareStatement("select usmSessionId from USMSession where " + PersistentSessionDataSQLStatements.DEVICE_IN_CONTEXT);
+            statement.setInt(1, contextId);
+            statement.setString(2, device);
+            statement.setString(3, protocol);
+            ResultSet result = statement.executeQuery();
+            sessionFound = result.next();
+        } catch (SQLException e) {
+            String errorMessage = " SQL error while retrieving session from DB";
+            throw new USMSQLException(USMSessionManagementErrorCodes.PERSISTENT_SESSION_DB_ERROR_2, errorMessage, e);
+        } finally {
+            Toolkit.close(statement);
+            Toolkit.close(con);
         }
-        return false;
+        
+        return sessionFound;
     }
 
     public Session getSession(String user, String password, String protocol, String device, SessionInitializer initializer, String clientIP, Map<String, String> xHeaders) throws USMException {
@@ -476,8 +469,10 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
                     _oxAjaxAccess.login(session);
                 }
                 session.updateClientIp(clientIP);
-                if (recheckUSMAccess(initializer, session))
+                if (recheckUSMAccess(initializer, session)) {
+                    updateLastUSMAccess(session);
                     return session;
+                }
             } catch (USMException e) {
                 _sessionStorage.removeSession(session);
                 throw e;
@@ -495,10 +490,25 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         session.initialize(configuration);
         _sessionStorage.storeSession(session);
         _usmCacheInformation.newSessionCreated();
-        session.setPersistentField(LAST_ACCESS_FIELD_NAME, String.valueOf(System.currentTimeMillis()));
+        updateLastUSMAccess(session);
         return session;
     }
 
+    private static void updateLastUSMAccess(SessionImpl session) throws USMSQLException, DatabaseAccessException {
+        long now = System.currentTimeMillis();
+        String oldStringValue = session.getPersistentField(LAST_ACCESS_FIELD_NAME);
+        if(oldStringValue != null) {
+            try {
+                long lastAccess = Long.parseLong(oldStringValue);
+                if(now - lastAccess < LAST_ACCESS_UPDATE_INTERVAL)
+                    return; // Last access timestamp is not too old, do nothing
+            } catch(NumberFormatException ignored) {
+                // ignore any invalid data, and simple fall through and store the current timestamp
+            }
+        }
+        session.setPersistentField(LAST_ACCESS_FIELD_NAME, String.valueOf(now));
+    }
+    
     private boolean recheckUSMAccess(SessionInitializer initializer, SessionImpl session) throws USMException {
         long now = System.currentTimeMillis();
         if (session.getLastAccessCheck() >= now - ACCESS_CHECK_INTERVAL)
@@ -561,10 +571,6 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         return _maxSyncStatesInDB;
     }
 
-    public boolean isKeepLastSentSyncStateInDB() {
-        return _keepLastSentSyncStateInDB;
-    }
-
     // --- Interface OXEventListener ---
 
     public void folderChanged(int contextId, int userId, String folderId, long timestamp) {
@@ -672,7 +678,8 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
 
     public void storeUUID(int cid, ContentType contentType, int objectId, UUID uuid, int folderOwner) throws DatabaseAccessException, USMSQLException, UUIDAlreadyMappedException, OXObjectAlreadyMappedException {
         OXObjectID oxObjectId = new OXObjectID(cid, contentType.getCode(), objectId);
-        _uuidService.storeMapping(getModifedUUID(uuid, folderOwner), oxObjectId);
+        if(_uuidService != null)
+            _uuidService.storeMapping(getModifedUUID(uuid, folderOwner), oxObjectId);
     }
 
     // public void storeOrRemapUUID(int cid, ContentType contentType, int objectId, UUID uuid)
@@ -710,8 +717,10 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         default:
             try {
                 int objectId = Integer.parseInt(o.getID());
-                UUID uuid = _uuidService.getUUID(o.getSession().getContextId(), contentTypeCode, objectId);
-                o.setUUID(useModifiedUUID ? getModifedUUID(uuid, o.getParentFolderOwnerID()) : uuid);
+                if (_uuidService != null) {
+                    UUID uuid = _uuidService.getUUID(o.getSession().getContextId(), contentTypeCode, objectId);
+                    o.setUUID(useModifiedUUID ? getModifedUUID(uuid, o.getParentFolderOwnerID()) : uuid);
+                }
             } catch (NumberFormatException ignored) {
             }
             break;
@@ -811,10 +820,6 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         return _waitForChangesEmailMinPullDelay;
     }
 
-    public void setKeepLastSentSyncStateInDB(boolean set) {
-        _keepLastSentSyncStateInDB = set;
-    }
-
     public void setMaxSyncStatesInDB(int states) {
         _maxSyncStatesInDB = states;
     }
@@ -917,10 +922,6 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         return SPECIAL_FOLDERS_VIEW;
     }
 
-    public boolean isForceNewSyncKeyOnEmptySync() {
-        return _forceNewSyncKeyOnEmptySync;
-    }
-
     public int getSessionCacheTimeout() {
         return _sessionCacheTimeout;
     }
