@@ -233,13 +233,11 @@ public class SyncStateStorage {
         long oldTS = timestampToKeep;
         if (timestamps != null && timestamps.length > 0) {
             long newestTimestamp = getNewestTimestamp(timestamps);
-            if (!session.getSessionManager().isForceNewSyncKeyOnEmptySync()) {
-                byte[] newestData = getCompressedData(objectID, newestTimestamp);
-                if (Arrays.equals(data, newestData) || !hasStateChanged(newestTimestamp, newestData, objectSet, session)) {
-                    if (journal.isDebugEnabled())
-                        journal.debug(_session + " Storing in DB cache not necessary, no changes for " + objectID + ", timestamp " + timestamp + "->" + newestTimestamp + ", keeping " + timestampToKeep);
-                    return newestTimestamp;
-                }
+            byte[] newestData = getCompressedData(objectID, newestTimestamp);
+            if (Arrays.equals(data, newestData) || !hasStateChanged(newestTimestamp, newestData, objectSet, session)) {
+                if (journal.isDebugEnabled())
+                    journal.debug(_session + " Storing in DB cache not necessary, no changes for " + objectID + ", timestamp " + timestamp + "->" + newestTimestamp + ", keeping " + timestampToKeep);
+                return newestTimestamp;
             }
             newTS = Math.max(newestTimestamp + 1L, newTS);
         }
