@@ -115,13 +115,7 @@ public class USMCacheInformation {
     }
 
     public int getTotalSyncStatesInMemory() {
-        int count = 0;
-        for (SessionReference reference : _sessionManager.getSessionStorage().getSessionReferences()) {
-            SessionImpl session = reference.poll();
-            if (session != null)
-                count += session.getDataObjectCache().getSyncStateCount();
-        }
-        return count;
+        return _sessionManager.getSyncStateCacheProvider().getSyncStateCount();
     }
 
     public void clearCacheCounters() {
