@@ -81,7 +81,6 @@ public class USMSessionCacheCleanupTask implements Runnable {
                 log.debug("Removing USM Sessions/SyncStates from memory cache that have not been accessed for " + sessionCacheTimeout + '/' + syncStateCacheTimeout + " seconds");
             SessionStorage storage = _sessionManager.getSessionStorage();
             int removedSessions = 0;
-            int removedSyncStates = 0;
             for (SessionReference ref : storage.getSessionReferences()) {
                 if (ref.getLastAccess() < sessionLimit) {
                     SessionImpl session = ref.get();
@@ -89,13 +88,9 @@ public class USMSessionCacheCleanupTask implements Runnable {
                         storage.removeSession(session);
                         removedSessions++;
                     }
-                } else {
-                    SessionImpl session = ref.poll();
-                    if (session != null) {
-                        removedSyncStates += session.getDataObjectCache().removeOldCachedData(syncStateLimit);
-                    }
                 }
             }
+            int removedSyncStates = _sessionManager.getSyncStateCacheProvider().removeUnusedSyncStates(syncStateLimit);
             int jvmRemovals = storage.removeClearedReferences();
             _sessionManager.updateCacheRemovals(removedSessions, jvmRemovals, removedSyncStates);
         } catch (Exception e) {
