@@ -111,8 +111,6 @@ public class USMSessionManagementErrorCodes {
 
     public static final int CONFIGURATION_ERROR_6 = 0x30001D;
 
-    public static final int CONFIGURATION_ERROR_7 = 0x30001E;
-
     public static final int CONFIGURATION_ERROR_8 = 0x30001F;
 
     public static final int FOLDER_NOT_FOUND = 0x300020;
@@ -123,8 +121,6 @@ public class USMSessionManagementErrorCodes {
 
     public static final int CONFIGURATION_ERROR_11 = 0x300023;
 
-    public static final int CONFIGURATION_ERROR_13 = 0x300025;
-
     public static final int CONFIGURATION_ERROR_14 = 0x300026;
 
     public static final int CONFIGURATION_ERROR_15 = 0x300027;
@@ -136,6 +132,8 @@ public class USMSessionManagementErrorCodes {
     public static final int CONFIGURATION_ERROR_18 = 0x30002A;
 
     public static final int CONFIGURATION_ERROR_19 = 0x30002B;
+
+    public static final int CONFIGURATION_ERROR_20 = 0x30002C;
     
     
     public static final int UUID_GENERATE_OBJECT_ID_ERROR = 0x300031;
@@ -167,6 +165,8 @@ public class USMSessionManagementErrorCodes {
     public static final int SESSION_TIMESTAMP_DB_ERROR_1 = 0x300046;
 
     public static final int SESSION_TIMESTAMP_DB_ERROR_2 = 0x300047;
+    
+    public static final int ILLEGAL_OBJETCS_TO_BE_SAVED_IN_SYNC_STATE = 0x300048;
 
     public static final int SESSION_INITIALIZATION_FAILED = 0x300100;
 }
