@@ -123,6 +123,8 @@ public class IncrementalContentSyncer extends BaseContentSyncer {
 			for (Iterator<DataObject> i = serverCreations.iterator(); i.hasNext();) {
 				DataObject sf = i.next();
 				DataObject cf = clientDataObjects.get(sf.getID());
+				if(cf == null)
+				    cf = storage.findMatchingClientObjectForServerObject(clientDataObjects, sf);
 				if (cf == null) {
 					// Lookup UUID for all DataObjects that are new since the last sync state
 					newestCachedData = _sessionManager.insertStoredUUID(sf, cachedDataObjects, newestCachedData);
