@@ -186,17 +186,15 @@ public class UUIDMappingImpl implements UUIDMappingService {
 
 	public OXObjectID getMappedObject(int cid, UUID uuid) throws DatabaseAccessException, USMSQLException {
 		OXObjectID objectID = OXObjectID.fromSimplifiedUUID(_cacheUUIDtoOXObjectID.get(uuid));
-		if (objectID == null) {
-            objectID = getOXIdentifierFromDB(cid, uuid);
-        }
+		if (objectID == null)
+			objectID = getOXIdentifierFromDB(cid, uuid);
 		return objectID;
 	}
 
 	private UUID getMappedUUID(OXObjectID oxObjectId) throws DatabaseAccessException, USMSQLException {
 		UUID uuid = _cacheOXObjectIDtoUUID.get(oxObjectId.convertToSimplifiedUUID());
-		if (uuid == null) {
-            uuid = getUUIDFromDB(oxObjectId);
-        }
+		if (uuid == null)
+			uuid = getUUIDFromDB(oxObjectId);
 		return uuid;
 	}
 
@@ -204,9 +202,8 @@ public class UUIDMappingImpl implements UUIDMappingService {
 		OXObjectID oxObjectID = null;
 		EncapsulatedConnection con = null;
 		PreparedStatement statement = null;
-		if (_journal.isDebugEnabled()) {
-            _journal.debug("Retrieving OX object for UUID " + uuid);
-        }
+		if (_journal.isDebugEnabled())
+			_journal.debug("Retrieving OX object for UUID " + uuid);
 		try {
 			con = _dbAccess.getReadOnly(contextId);
 			statement = con.prepareStatement(SELECT_BY_UUID_PART1 + _dbAccess.retrieveUnHexFunctionName()
@@ -237,9 +234,8 @@ public class UUIDMappingImpl implements UUIDMappingService {
 		UUID uuid = null;
 		EncapsulatedConnection con = null;
 		PreparedStatement statement = null;
-		if (_journal.isDebugEnabled()) {
-            _journal.debug("Retrieving UUID for OX object " + oxObjectID);
-        }
+		if (_journal.isDebugEnabled())
+			_journal.debug("Retrieving UUID for OX object " + oxObjectID);
 		try {
 			con = _dbAccess.getReadOnly(oxObjectID.getCid());
 			statement = con.prepareStatement("SELECT " + _dbAccess.retrieveHexFunctionName() + SELECT_UUID);
@@ -284,18 +280,16 @@ public class UUIDMappingImpl implements UUIDMappingService {
 	private void saveIdentifierInDB(UUID uuid, OXObjectID oxObjectID) throws DatabaseAccessException, USMSQLException {
 		EncapsulatedConnection con = null;
 		PreparedStatement statement = null;
-		if (_journal.isDebugEnabled()) {
-            _journal.debug("Storing UUID " + uuid + " for OX object " + oxObjectID);
-        }
+		if (_journal.isDebugEnabled())
+			_journal.debug("Storing UUID " + uuid + " for OX object " + oxObjectID);
 		try {
 			con = _dbAccess.getWritable(oxObjectID.getCid());
 			statement = con.prepareStatement(FULL_INSERT_PART1 + _dbAccess.retrieveUnHexFunctionName()
 					+ FULL_INSERT_PART2);
 			setOxObjectParameters(oxObjectID, statement);
 			statement.setString(4, uuid.toString());
-			if (statement.executeUpdate() != 1) {
-                _journal.error(" Insert of object with UUID was not performed");
-            }
+			if (statement.executeUpdate() != 1)
+				_journal.error(" Insert of object with UUID was not performed");
 			storeUUIDMappingInCache(uuid, oxObjectID, true); // invalidate remote cache entries
 		} catch (SQLException e) {
 			String errorMessage = " SQL error saving uuid for " + oxObjectID.toString();
@@ -334,9 +328,8 @@ public class UUIDMappingImpl implements UUIDMappingService {
 			UUID simplifiedUUID = oxObjectID.convertToSimplifiedUUID();
 			UUID uuid = _cacheOXObjectIDtoUUID.get(simplifiedUUID);
 			_cacheOXObjectIDtoUUID.remove(simplifiedUUID);
-			if (uuid != null) {
-                _cacheUUIDtoOXObjectID.remove(uuid);
-            }
+			if (uuid != null)
+				_cacheUUIDtoOXObjectID.remove(uuid);
 		} catch (SQLException e) {
 			String errorMessage = " SQL error deleting mapping ";
 			_journal.error(errorMessage, e);
@@ -349,16 +342,15 @@ public class UUIDMappingImpl implements UUIDMappingService {
 
 	public UUID getContextUUID(int cid) throws DatabaseAccessException, USMSQLException {
 		UUID uuid = _contextUUIDs.get(cid);
-		if (uuid != null) {
-            return uuid;
-        }
+		if (uuid != null)
+			return uuid;
 
 		EncapsulatedConnection con = null;
 		PreparedStatement statement = null;
 		ResultSet result = null;
 
 		try {
-			con = _dbAccess.getWritable(cid);
+			con = _dbAccess.getReadOnly(cid);
 			statement = con.prepareStatement("SELECT header FROM UUIDHeader where cid = ?");
 			statement.setInt(1, cid);
 
@@ -368,14 +360,15 @@ public class UUIDMappingImpl implements UUIDMappingService {
 			} else {
 				Toolkit.close(result);
 				Toolkit.close(statement);
+				Toolkit.close(con);
 				//generate the header
 				uuid = UUID.randomUUID();
+				con = _dbAccess.getWritable(cid);
 				statement = con.prepareStatement("INSERT INTO UUIDHeader (cid, header) VALUES(?, ?)");
 				statement.setInt(1, cid);
 				statement.setString(2, uuid.toString());
-				if (statement.executeUpdate() != 1) {
-                    _journal.error("Insert of UUID header was not performed for cid " + cid);
-                }
+				if (statement.executeUpdate() != 1)
+					_journal.error("Insert of UUID header was not performed for cid " + cid);
 			}
 		} catch (SQLException e) {
 			String errorMessage = " SQL error getting UUID header ";
